@@ -2,21 +2,22 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
+
 #ifndef __AC_INTERFACEBUTTON_H
 #define __AC_INTERFACEBUTTON_H
 
-#if defined (OBSOLETE)
-
 #define MAXBUTTON       20
+#define IBACT_SETMODE   1
+#define IBACT_SCRIPT    2
 #define IBFLG_ENABLED   1
 #define IBFLG_INVBOX    2
 struct InterfaceButton {
@@ -27,6 +28,4 @@ struct InterfaceButton {
     void set(int xx, int yy, int picc, int overpicc, int actionn);
 };
 
-#endif // OBSOLETE
-
-#endif // __AC_INTERFACEBUTTON_H
+#endif // __AC_INTERFACEBUTTON_H
\ No newline at end of file
