@@ -2,13 +2,13 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
 //
@@ -28,7 +28,7 @@ namespace Common
 class TextWriter
 {
 public:
-    virtual ~TextWriter() = default;
+    virtual ~TextWriter(){}
 
     virtual bool    IsValid() const                         = 0;
 
@@ -41,9 +41,6 @@ public:
     // Write formatted string (see *printf)
     virtual void    WriteFormat(const char *fmt, ...)       = 0;
     virtual void    WriteLineBreak()                        = 0;
-
-    // Flushes the underlying device (does nothing in def impl)
-    virtual void    Flush() { /* do nothing */ }
 };
 
 } // namespace Common
