@@ -7,6 +7,7 @@ namespace AGS.CScript.Compiler
 	internal class ScalarVariableTypeToken : Token
 	{
 		private int _memorySizeInBytes;
+        private bool _isLegacyString = false;
 
 		public ScalarVariableTypeToken(string name, int memorySizeInBytes)
 			: base(name, true, true)
@@ -14,6 +15,12 @@ namespace AGS.CScript.Compiler
 			_memorySizeInBytes = memorySizeInBytes;
 		}
 
+        public ScalarVariableTypeToken(string name, int memorySizeInBytes, bool isLegacyString)
+            : this(name, memorySizeInBytes)
+        {
+            _isLegacyString = isLegacyString;
+        }
+
 		public int SizeInBytes
 		{
 			get { return _memorySizeInBytes; }
