@@ -14,7 +14,6 @@ namespace AGS.Editor
         private const string AUTO_COMPLETE_STATIC_ONLY = "$AUTOCOMPLETESTATICONLY$";
         private const string AUTO_COMPLETE_NO_INHERIT = "$AUTOCOMPLETENOINHERIT$";
         private static Script _scriptToUpdateInBackground = null;
-        private static List<Script> _importedScripts = null;
         private static object _scriptLockObject = new object();
 
         public delegate void BackgroundCacheUpdateStatusChangedHandler(BackgroundAutoCompleteStatus status, Exception errorDetails);
@@ -29,12 +28,11 @@ namespace AGS.Editor
             thread.Start();
         }
 
-        public static void RequestBackgroundCacheUpdate(Script scriptToUpdate, List<Script> importedScripts)
+        public static void RequestBackgroundCacheUpdate(Script scriptToUpdate)
         {
             lock (_scriptLockObject)
             {
                 _scriptToUpdateInBackground = scriptToUpdate;
-                _importedScripts = importedScripts;
             }
         }
 
@@ -54,18 +52,17 @@ namespace AGS.Editor
                 if (_scriptToUpdateInBackground != null)
                 {
                     Script scriptToUpdate;
-                    List<Script> importedScripts;
                     lock (_scriptLockObject)
                     {
                         scriptToUpdate = _scriptToUpdateInBackground;
-                        importedScripts = _importedScripts;
                         _scriptToUpdateInBackground = null;
-                        _importedScripts = null;
                     }
                     try
                     {
                         OnBackgroundCacheUpdateStatusChanged(BackgroundAutoCompleteStatus.Processing, null);
-                        ConstructCache(scriptToUpdate, importedScripts);
+
+                        ConstructCache(scriptToUpdate, true);
+
                         OnBackgroundCacheUpdateStatusChanged(BackgroundAutoCompleteStatus.Finished, null);
                     }
                     catch (Exception ex)
@@ -76,35 +73,33 @@ namespace AGS.Editor
             }
         }
 
+        public static void ConstructCache(Script scriptToCache)
+        {
+            ConstructCache(scriptToCache, false);
+        }
+
         private static bool IncrementIndexToSkipAnyComments(FastString script, ref int index)
         {
-            while (index < script.Length - 1 && (script[index] == '/'))
+            if (index < script.Length - 1)
             {
-                if ((script[index + 1] == '/'))
+                if ((script[index] == '/') && (script[index + 1] == '/'))
                 {
-                    index = IndexOfLineEnd(script, index + 2).Item2;
-                    if (index < 0)
+                    while ((script[index] != '\r') && (index < script.Length - 1))
                     {
-                        index = script.Length;
+                        index++;
                     }
                 }
-                else
+                if ((script[index] == '/') && (script[index + 1] == '*'))
                 {
-                    if ((script[index + 1] == '*'))
+                    index = script.IndexOf("*/", index + 2);
+                    if (index < 0)
                     {
-                        index = script.IndexOf("*/", index + 2);
-                        if (index < 0)
-                        {
-                            index = script.Length;
-                        }
-                    }
-                    else
-                    {
-                        break;
+                        index = script.Length - 1;
+                        return true;
                     }
                 }
             }
-            return index == script.Length;
+            return false;
         }
 
         private static void SkipUntilMatchingClosingBrace(ref FastString script)
@@ -144,7 +139,7 @@ namespace AGS.Editor
             script = script.Substring(index);
         }
 
-        public static void ConstructCache(Script scriptToCache, IEnumerable<Script> importScripts)
+        private static void ConstructCache(Script scriptToCache, bool isBackgroundThread)
         {
             string originalText = scriptToCache.Text;
             ScriptAutoCompleteData newCache = new ScriptAutoCompleteData();
@@ -161,16 +156,18 @@ namespace AGS.Editor
             FastString script = originalText;
             AutoCompleteParserState state = new AutoCompleteParserState();
             ScriptFunction lastFunction = null;
-            // Struct lookup will have both local and imported types
-            List<ScriptStruct> structsLookup = new List<ScriptStruct>();
-            if (importScripts != null)
-            {
-                foreach (var import in importScripts)
-                    structsLookup.AddRange(import.AutoCompleteData.Structs);
-            }
+            int counter = 0;
 
             while (script.Length > 0)
             {
+                if (isBackgroundThread)
+                {
+                    counter++;
+                    if (counter % 20 == 0)
+                    {
+                        Thread.Sleep(2);
+                    }
+                }
                 SkipWhitespace(ref script);
                 state.CurrentScriptCharacterIndex = originalText.Length - script.Length;
 
@@ -185,7 +182,7 @@ namespace AGS.Editor
 
                     if (scriptAtComment.StartsWith("///"))
                     {
-                        FastString commentText = scriptAtComment.Substring(3, (scriptAtComment.Length - script.Length) - 3);
+                        FastString commentText = scriptAtComment.Substring(3, (scriptAtComment.Length - script.Length) - 4);
                         state.PreviousComment = commentText.ToString().Trim();
                     }
                     continue;
@@ -209,12 +206,12 @@ namespace AGS.Editor
                 {
                     if (state.WordBeforeLast == "enum")
                     {
-                        state.InsideEnumDefinition = new ScriptEnum(state.LastWord, state.InsideIfDefBlock, state.InsideIfNDefBlock, state.CurrentScriptCharacterIndex);
+                        state.InsideEnumDefinition = new ScriptEnum(state.LastWord, state.InsideIfDefBlock, state.InsideIfNDefBlock);
                     }
                     else if (state.WordBeforeLast == "extends")
                     {
                         // inherited struct
-                        foreach (ScriptStruct baseStruct in structsLookup)
+                        foreach (ScriptStruct baseStruct in structs)
                         {
                             if (baseStruct.Name == state.LastWord)
                             {
@@ -249,26 +246,8 @@ namespace AGS.Editor
                 if (thisWord == "(")
                 {
                     List<ScriptFunction> functionList = functions;
-                    bool isStaticExtender = script.StartsWith("static ");
-                    bool isExtenderMethod = isStaticExtender || script.StartsWith("this ");
-                    if (isExtenderMethod)
-                    {
-                        ScriptStruct newStruct = null;
-                        // NOTE: for extenders we DO NOT look up the global struct list;
-                        // the reason is a bit complicated, but in a nutshell:
-                        // we need to have a list of extender functions bound to the
-                        // struct defs in the *local* script's autocomplete cache, not the
-                        // imported script's cache. The struct defs may be duplicated this
-                        // way, but that's mostly fine, as these may be merged together;
-                        // e.g. see ScintillaWrapper.GetAllStructsWithMatchingName().
-                        AdjustFunctionListForExtenderFunction(structs, ref functionList, ref newStruct, ref script);
-                        if (newStruct != null)
-                        {
-                            structs.Add(newStruct);
-                            structsLookup.Add(newStruct);
-                        }
-                    }
-                    if (AddFunctionDeclaration(functionList, ref script, thisWord, state, isExtenderMethod, isStaticExtender, isStaticExtender))
+                    bool isExtenderMethod = AdjustFunctionListForExtenderFunction(structs, ref functionList, ref script);
+                    if (AddFunctionDeclaration(functionList, ref script, thisWord, state, isExtenderMethod))
                     {
                         lastFunction = functionList[functionList.Count - 1];
                     }
@@ -277,6 +256,7 @@ namespace AGS.Editor
 				else if ((thisWord == "[") && (PeekNextWord(script) == "]"))
 				{
 					GetNextWord(ref script);
+					state.DynamicArrayDefinition = true;
 					state.AddNextWord("[]");
 				}
 				else if ((thisWord == "=") || (thisWord == ";") ||
@@ -284,7 +264,7 @@ namespace AGS.Editor
 				{
 					if (state.InsideEnumDefinition != null)
 					{
-						AddEnumValue(state.InsideEnumDefinition, script, state.LastWord, state);
+						AddEnumValue(state.InsideEnumDefinition, script, state.LastWord);
 
                         if (thisWord == "=")
                         {
@@ -321,13 +301,14 @@ namespace AGS.Editor
 						}
 					}
 					state.ClearPreviousWords();
+					state.DynamicArrayDefinition = false;
 				}
 				else if ((thisWord == "}") && (state.InsideEnumDefinition != null))
 				{
                     // add the last value (unless it's an empty enum)
                     if (state.LastWord != "{")
                     {
-                        AddEnumValue(state.InsideEnumDefinition, script, state.LastWord, state);
+                        AddEnumValue(state.InsideEnumDefinition, script, state.LastWord);
                     }
 					enums.Add(state.InsideEnumDefinition);
 					state.InsideEnumDefinition = null;
@@ -336,10 +317,8 @@ namespace AGS.Editor
 				else if ((thisWord == "}") && (state.InsideStructDefinition != null))
 				{
 					structs.Add(state.InsideStructDefinition);
-                    structsLookup.Add(state.InsideStructDefinition);
-                    // Restore struct member references to global script ones
-                    functions = newCache.Functions;
-                    variables = newCache.Variables;
+					functions = newCache.Functions;
+					variables = newCache.Variables;
                     state.InsideStructDefinition = null;
                     state.ClearPreviousWords();
 				}
@@ -348,83 +327,40 @@ namespace AGS.Editor
 					state.AddNextWord(thisWord);
 				}
             }
-
-            GenerateDynamicArrayStructs(newCache, structsLookup);
-
             scriptToCache.AutoCompleteData.CopyFrom(newCache);
 			scriptToCache.AutoCompleteData.Populated = true;
         }
 
-        private static void GenerateDynamicArrayStructs(ScriptAutoCompleteData data, List<ScriptStruct> structsLookup)
+        private static bool AdjustFunctionListForExtenderFunction(List<ScriptStruct> structs, ref List<ScriptFunction> functionList, ref FastString script)
         {
-            GenerateDynamicArrayStructs(data.Variables, data.Structs, structsLookup);
-        }
-
-        private static void GenerateDynamicArrayStructs(List<ScriptVariable> variables, List<ScriptStruct> structs, List<ScriptStruct> structsLookup)
-        {
-            List<ScriptStruct> structsCopy = new List<ScriptStruct>(structs);
-
-            GenerateDynamicArrayStructsIntern(variables, structs, structsLookup);
-            foreach (var s in structsCopy)
-                GenerateDynamicArrayStructsIntern(s.Variables, structs, structsLookup);
-        }
-
-        private static void GenerateDynamicArrayStructsForVarsOnly(List<ScriptVariable> variables, List<ScriptStruct> structs)
-        {
-            List<ScriptStruct> structsLookup = new List<ScriptStruct>(structs);
-            GenerateDynamicArrayStructsIntern(variables, structs, structsLookup);
-        }
-
-        private static void GenerateDynamicArrayStructsIntern(List<ScriptVariable> variables, List<ScriptStruct> structs, List<ScriptStruct> structsLookup)
-        {
-            foreach (var variable in variables)
+            if (script.StartsWith("this "))
             {
-                if (!variable.IsDynamicArray)
-                    continue;
-
-                string trueType = variable.Type;
-                string fakeStructName = trueType + (variable.IsPointer ? "*[]" : "[]");
-                variable.Type = fakeStructName;
-                if (structsLookup.Find(s => s.Name == fakeStructName) != null)
-                    continue;
-
-                ScriptStruct dynArrStruct = new ScriptStruct(fakeStructName);
-                ScriptVariable lengthVar = new ScriptVariable("Length", "int", false, false, false, null, null, false, false, false, false, true, 0);
-                lengthVar.Description = "Returns length of this dynamic array.";
-                dynArrStruct.Variables.Add(lengthVar);
-                dynArrStruct.BaseType = trueType;
-                dynArrStruct.FullDefinition = true;
-                structs.Add(dynArrStruct);
-                structsLookup.Add(dynArrStruct);
-            }
-        }
-
-        private static void AdjustFunctionListForExtenderFunction(List<ScriptStruct> structsLookup,
-            ref List<ScriptFunction> functionList, ref ScriptStruct newStruct, ref FastString script)
-        {
-            GetNextWord(ref script);
-            string structName = GetNextWord(ref script);
-            while ((script.Length > 0) && (script[0] != ',') && (script[0] != ')'))
-            {
-                script = script.Substring(1);
-            }
-            if ((script.Length > 0) && script[0] == ',')
-            {
-                script = script.Substring(1);
-            }
-            script = script.Trim();
-
-            foreach (ScriptStruct struc in structsLookup)
-            {
-                if (struc.Name == structName)
+                GetNextWord(ref script);
+                string structName = GetNextWord(ref script);
+                while ((script.Length > 0) && (script[0] != ',') && (script[0] != ')'))
                 {
-                    functionList = struc.Functions;
-                    return;
+                    script = script.Substring(1);
                 }
+                if ((script.Length > 0) && script[0] == ',')
+                {
+                    script = script.Substring(1);
+                }
+                script = script.Trim();
+
+                foreach (ScriptStruct struc in structs)
+                {
+                    if (struc.Name == structName)
+                    {
+                        functionList = struc.Functions;
+                        return true;
+                    }
+                }
+                ScriptStruct newStruct = new ScriptStruct(structName);
+                functionList = newStruct.Functions;
+                structs.Add(newStruct);
+                return true;
             }
-            newStruct = new ScriptStruct(structName);
-            functionList = newStruct.Functions;
-            return;
+            return false;
         }
 
         private static ScriptStruct CreateInheritedStruct(ScriptStruct baseStruct, AutoCompleteParserState state)
@@ -454,16 +390,16 @@ namespace AGS.Editor
             if (preProcessorDirective == "define")
             {
                 string macroName = GetNextWord(ref script);
-                if (!string.IsNullOrEmpty(macroName) && (Char.IsLetter(macroName[0])) &&
+                if ((Char.IsLetter(macroName[0])) &&
                     (!DoesCurrentLineHaveToken(script, AUTO_COMPLETE_IGNORE)))
                 {
-                    defines.Add(new ScriptDefine(macroName, state.InsideIfDefBlock, state.InsideIfNDefBlock, state.CurrentScriptCharacterIndex));
+                    defines.Add(new ScriptDefine(macroName, state.InsideIfDefBlock, state.InsideIfNDefBlock));
                 }
             }
             else if (preProcessorDirective == "undef")
             {
                 string macroName = GetNextWord(ref script);
-                if (!string.IsNullOrEmpty(macroName) && Char.IsLetter(macroName[0]))
+                if (Char.IsLetter(macroName[0]))
                 {
                     foreach (ScriptDefine define in defines)
                     {
@@ -478,7 +414,7 @@ namespace AGS.Editor
             else if (preProcessorDirective == "ifndef")
             {
                 string macroName = GetNextWord(ref script);
-                if (!string.IsNullOrEmpty(macroName) && Char.IsLetter(macroName[0]))
+                if (Char.IsLetter(macroName[0]))
                 {
                     state.InsideIfNDefBlock = macroName;
                 }
@@ -486,25 +422,11 @@ namespace AGS.Editor
             else if (preProcessorDirective == "ifdef")
             {
                 string macroName = GetNextWord(ref script);
-                if (!string.IsNullOrEmpty(macroName) && Char.IsLetter(macroName[0]))
+                if (Char.IsLetter(macroName[0]))
                 {
                     state.InsideIfDefBlock = macroName;
                 }
             }
-            else if (preProcessorDirective == "else")
-            {
-                // Negate previous condition
-                if (state.InsideIfDefBlock != null)
-                {
-                    state.InsideIfNDefBlock = state.InsideIfDefBlock;
-                    state.InsideIfDefBlock = null;
-                }
-                else if (state.InsideIfNDefBlock != null)
-                {
-                    state.InsideIfDefBlock = state.InsideIfNDefBlock;
-                    state.InsideIfNDefBlock = null;
-                }
-            }
             else if (preProcessorDirective == "endif")
             {
                 state.InsideIfNDefBlock = null;
@@ -514,42 +436,23 @@ namespace AGS.Editor
             state.ClearPreviousWords();
         }
 
-        private static void AddEnumValue(ScriptEnum insideEnumDefinition, FastString script, string lastWord, AutoCompleteParserState state)
+        private static void AddEnumValue(ScriptEnum insideEnumDefinition, FastString script, string lastWord)
         {
             if ((lastWord.Length > 0) && (Char.IsLetter(lastWord[0])))
             {
                 if (!DoesCurrentLineHaveToken(script, AUTO_COMPLETE_IGNORE))
                 {
-                    insideEnumDefinition.EnumValues.Add(new ScriptEnumValue(lastWord, insideEnumDefinition.Name, state.InsideIfDefBlock, state.InsideIfNDefBlock, state.CurrentScriptCharacterIndex));
+                    insideEnumDefinition.EnumValues.Add(lastWord);
                 }
             }
         }
 
-        /// <summary>
-        /// Searches for any line-break (LF or CRLF), and returns a pair of character indexes:
-        /// an index of line-break, and an index right after line-break.
-        /// </summary>
-        private static Tuple<int, int> IndexOfLineEnd(FastString script, int fromIndex = 0)
-        {
-            int indexofLF = script.IndexOf('\n', fromIndex);
-            if (indexofLF < 0)
-                return new Tuple<int, int>(-1, -1);
-            if (indexofLF > 0 && script[indexofLF - 1] == '\r')
-            {
-                return new Tuple<int, int>(indexofLF - 1, indexofLF + 1);
-            }
-            else
-            {
-                return new Tuple<int, int>(indexofLF, indexofLF + 1);
-            }
-        }
-
         private static bool DoesCurrentLineHaveToken(FastString script, string tokenToCheckFor)
         {
-            var indexOfNextLine = IndexOfLineEnd(script);
-            if (indexOfNextLine.Item1 > 0)
+            int indexOfNextLine = script.IndexOf("\r\n");
+            if (indexOfNextLine > 0)
             {
-                if (script.Substring(0, indexOfNextLine.Item1).IndexOf(tokenToCheckFor) > 0)
+                if (script.Substring(0, indexOfNextLine).IndexOf(tokenToCheckFor) > 0)
                 {
                     return true;
                 }
@@ -557,7 +460,7 @@ namespace AGS.Editor
             return false;
         }
 
-        private static bool AddFunctionDeclaration(List<ScriptFunction> functions, ref FastString script, string thisWord, AutoCompleteParserState state, bool isExtenderMethod, bool isStatic, bool isStaticOnly)
+        private static bool AddFunctionDeclaration(List<ScriptFunction> functions, ref FastString script, string thisWord, AutoCompleteParserState state, bool isExtenderMethod)
         {
             bool succeeded = false;
 
@@ -568,6 +471,7 @@ namespace AGS.Editor
                     string functionName = state.LastWord;
                     string type = state.WordBeforeLast;
                     bool isPointer = false, isNoInherit = false;
+                    bool isStatic = false, isStaticOnly = false;
                     bool isProtected = false;
                     if (type == "::")
                     {
@@ -579,10 +483,10 @@ namespace AGS.Editor
                         isPointer = true;
                         type = state.WordBeforeWordBeforeLast;
                     }
-					if (type == "[]")
+					if (state.DynamicArrayDefinition)
 					{
 						// get the type name and the []
-						type = state.WordBeforeWordBeforeLast + "[]";
+						type = state.WordBeforeWordBeforeLast + state.WordBeforeLast;
 					}
                     if (state.IsWordInPreviousList("static"))
                     {
@@ -615,6 +519,7 @@ namespace AGS.Editor
                         functions.Add(newFunc);
                         succeeded = true;
                     }
+					state.DynamicArrayDefinition = false;
                 }
             }
 
@@ -627,71 +532,33 @@ namespace AGS.Editor
             {
                 if (!DoesCurrentLineHaveToken(script, AUTO_COMPLETE_IGNORE))
                 {
-                    bool isAttribute = false;
-                    bool isArray = false, isDynamicArray = false;
-                    bool isPointer = false;
+                    bool isArray = false, isPointer = false;
                     bool isStatic = false, isStaticOnly = false;
                     bool isNoInherit = false, isProtected = false;
-                    bool isReadonly = false;
                     string type = state.WordBeforeLast;
-                    int typeWordIndex = 1;
 					string varName = state.LastWord;
-
-                    isAttribute = state.IsWordInPreviousList("attribute");
-
                     if (thisWord == "[")
                     {
                         while ((script.Length > 0) && (GetNextWord(ref script) != "]")) ;
                         isArray = true;
                     }
-					else
+					else if (state.DynamicArrayDefinition)
 					{
-                        // Dynarray brackets may be met in following cases:
-                        // - indexed attribute (attribute type name[])
-                        // - dynamic array (type name[])
-                        // - attribute returning dynamic array (attribute type[] name)
-                        // - indexed attribute returning dynamic array (attribute type[] name[])
-                        if (varName == "[]")
-                        {
-                            // it's appended to the name
-                            varName = state.WordBeforeLast;
-                            type = state.WordBeforeWordBeforeLast;
-                            typeWordIndex = 2;
-                            if (isAttribute)
-                            {
-                                // indexed attribute
-                            }
-                            else
-                            {
-                                // regular variable of dynamic array type
-                                isArray = true;
-                                isDynamicArray = true;
-                            }
-                        }
-
-                        if (type == "[]")
-                        {
-                            typeWordIndex++;
-                            type = state.PreviousWords[typeWordIndex];
-                            // it's appended to a type
-                            if (isAttribute)
-                            {
-                                // attribute returning dynamic array
-                                isArray = true;
-                                isDynamicArray = true;
-                            }
-                            else
-                            {
-                                // bad syntax?
-                            }
-                        }
-                    }
-
+						varName = state.WordBeforeLast;
+						type = state.WordBeforeWordBeforeLast;
+						isArray = true;
+					}
                     if (type == "*")
                     {
                         isPointer = true;
-                        typeWordIndex++;
-                        type = state.PreviousWords[typeWordIndex];
+                        if (state.DynamicArrayDefinition)
+                        {
+                            type = state.PreviousWords[3];
+                        }
+                        else
+                        {
+                            type = state.WordBeforeWordBeforeLast;
+                        }
                     }
                     if (state.IsWordInPreviousList("static"))
                     {
@@ -701,10 +568,6 @@ namespace AGS.Editor
                     {
                         isProtected = true;
                     }
-                    if (state.IsWordInPreviousList("readonly"))
-                    {
-                        isReadonly = true;
-                    }
                     if (DoesCurrentLineHaveToken(script, AUTO_COMPLETE_STATIC_ONLY))
                     {
                         isStaticOnly = true;
@@ -717,7 +580,7 @@ namespace AGS.Editor
                     if (type != "struct")
                     {
                         //if (varName == "{") System.Diagnostics.Debugger.Break();
-                        ScriptVariable newVar = new ScriptVariable(varName, type, isArray, isDynamicArray, isPointer, state.InsideIfDefBlock, state.InsideIfNDefBlock, isStatic, isStaticOnly, isNoInherit, isProtected, isReadonly, state.CurrentScriptCharacterIndex);
+                        ScriptVariable newVar = new ScriptVariable(varName, type, isArray, isPointer, state.InsideIfDefBlock, state.InsideIfNDefBlock, isStatic, isStaticOnly, isNoInherit, isProtected, state.CurrentScriptCharacterIndex);
 
                         if (!string.IsNullOrEmpty(state.PreviousComment))
                         {
@@ -728,19 +591,20 @@ namespace AGS.Editor
                         variables.Add(newVar);
                     }
                 }
+				state.DynamicArrayDefinition = false;
 			}
         }
 
         private static void GoToNextLine(ref FastString script)
         {
-            var indexOfNextLine = IndexOfLineEnd(script);
-            if (indexOfNextLine.Item1 < 0)
+            int indexOfNextLine = script.IndexOf("\r\n");
+            if (indexOfNextLine < 0)
             {
                 script = string.Empty;
             }
             else
             {
-                script = script.Substring(indexOfNextLine.Item2);
+                script = script.Substring(indexOfNextLine + 2);
             }
         }
 
@@ -782,7 +646,7 @@ namespace AGS.Editor
                 return string.Empty;
             }
             int index = 0;
-            while (script[index].IsScriptWordChar())
+            while (Char.IsLetterOrDigit(script[index]) || (script[index] == '_'))
             {
                 index++;
                 if (index >= script.Length)
@@ -807,64 +671,10 @@ namespace AGS.Editor
             return nextWord;
         }
 
-        public static List<ScriptVariable> GetLocalVariableDeclarations(ScriptFunction func, List<ScriptStruct> localStructs, string scriptToParse, int relativeCharacterIndex)
-        {
-            List<ScriptVariable> variables = new List<ScriptVariable>();
-            GetFunctionParametersAsVariableList(func, variables);
-            GetLocalVariableDeclarationsFromScriptExtract(scriptToParse, relativeCharacterIndex, variables);
-            GenerateDynamicArrayStructsForVarsOnly(variables, localStructs);
-            return variables;
-        }
-
-        private static void GetFunctionParametersAsVariableList(ScriptFunction func, List<ScriptVariable> variables)
-        {
-            if (func.ParamList.Length == 0)
-            {
-                return;
-            }
-            string[] parameters = func.ParamList.Split(',');
-            foreach (string thisParam in parameters)
-            {
-                FastString param = thisParam.Trim();
-                if (param.StartsWith("optional "))
-                {
-                    param = param.Substring(9).Trim();
-                }
-                int index = param.Length - 1;
-
-                bool isDynamicArray = false;
-                if (index >= 0 && param[index] == ']')
-                {
-                    isDynamicArray = true;
-                    while (index >= 0 && param[index--] != '[');
-                    param = param.Substring(0, index + 1).Trim();
-                }
-
-                while ((index >= 0) &&
-                       (Char.IsLetterOrDigit(param[index]) || param[index] == '_'))
-                {
-                    index--;
-                }
-                FastString paramName = param.Substring(index + 1);
-                FastString paramType = param.Substring(0, index + 1).Trim();
-                bool isPointer = false;
-                // FIXME: implement FastString EndsWith
-                if ((paramType.Length > 0) && paramType[paramType.Length - 1] == '*')
-                {
-                    isPointer = true;
-                    paramType = paramType.Substring(0, paramType.Length - 1).Trim();
-                }
-                if ((paramName.Length > 0) && (paramType.Length > 0))
-                {
-                    variables.Add(new ScriptVariable(paramName.ToString(), paramType.ToString(), false, isDynamicArray, isPointer, null, null, false, false, false, false, false, func.StartsAtCharacterIndex));
-                }
-            }
-            return;
-        }
-
-        private static void GetLocalVariableDeclarationsFromScriptExtract(string scriptToParse, int relativeCharacterIndex, List<ScriptVariable> variables)
+        public static List<ScriptVariable> GetLocalVariableDeclarationsFromScriptExtract(string scriptToParse, int relativeCharacterIndex)
         {
             FastString script = scriptToParse;
+            List<ScriptVariable> variables = new List<ScriptVariable>();
             string lastWord = string.Empty;
             while (script.Length > 0)
             {
@@ -891,13 +701,9 @@ namespace AGS.Editor
                         string variableName = nextWord;
                         nextWord = GetNextWord(ref script);
                         bool isArray = false;
-                        bool isDynamicArray = false;
                         if (nextWord == "[") 
                         {
                             isArray = true;
-                            if (PeekNextWord(script) == "]")
-                                isDynamicArray = true;
-
                             while ((script.Length > 0) && (GetNextWord(ref script) != "]")) ;
 							nextWord = GetNextWord(ref script);
                         }
@@ -905,7 +711,7 @@ namespace AGS.Editor
                         if (((nextWord == "=") || (nextWord == ";") || (nextWord == ",")) &&
                             (lastWord != "return") && (lastWord != "else"))
                         {
-							variables.Add(new ScriptVariable(variableName, lastWord, isArray, isDynamicArray, isPointer, null, null, false, false, false, false, false, (scriptToParse.Length - script.Length) + relativeCharacterIndex));
+							variables.Add(new ScriptVariable(variableName, lastWord, isArray, isPointer, null, null, false, false, false, false, (scriptToParse.Length - script.Length) + relativeCharacterIndex));
                         }
                         if (nextWord != ",")
                         {
@@ -922,7 +728,7 @@ namespace AGS.Editor
                     lastWord = string.Empty;
                 }
             }
-            return;
+            return variables;
         }
     }
 }
