@@ -9,7 +9,6 @@ namespace AGS.Editor
 	public class ComponentController
 	{
 		private List<IEditorComponent> _components;
-        private List<string> _supressedComponents;
 
 		private static ComponentController _instance;
 
@@ -28,19 +27,13 @@ namespace AGS.Editor
 		private ComponentController()
 		{
 			_components = new List<IEditorComponent>();
-            _supressedComponents = new List<string>();
-        }
+		}
 
 		public void AddComponent(IEditorComponent component)
 		{
 			_components.Add(component);
 		}
 
-        public void AddSuppressedComponent(string componentName)
-        {
-            _supressedComponents.Add(componentName);
-        }
-
         public IList<IEditorComponent> Components
         {
             get
@@ -53,17 +46,7 @@ namespace AGS.Editor
 		{
 			foreach (IEditorComponent component in _components)
 			{
-                try
-                {
-                    component.EditorShutdown();
-                }
-                catch(Exception e)
-                {
-                    // TODO: write into the Editor's log or something?
-                    GUIController.Instance.ShowError(
-                        string.Format($"Editor component {component.ComponentID} was shut down with an exception.",
-                        e, MessageBoxIconType.Warning));
-                }
+				component.EditorShutdown();
 			}
 		}
 
@@ -143,8 +126,7 @@ namespace AGS.Editor
 			{
 				if (componentNodes[componentID].HasChildNodes)
 				{
-                    if (!_supressedComponents.Contains(componentID))
-					    missingComponents.Add(componentID);
+					missingComponents.Add(componentID);
 				}
 			}
 			return missingComponents;
@@ -195,19 +177,6 @@ namespace AGS.Editor
             }
         }
 
-		public IEditorComponent FindComponentThatManageScriptElement(string scriptType)
-		{
-			foreach (IEditorComponent component in _components)
-			{
-				if (component is Components.BaseComponent)
-				{
-					Components.BaseComponent bComponent = component as Components.BaseComponent;
-					if (bComponent.GetManagedScriptElements().Contains(scriptType)) return bComponent;
-				}
-			}
-			return null;
-		}
-
 		public IEditorComponent FindComponentThatImplementsInterface(Type interfaceType)
 		{
 			foreach (IEditorComponent component in _components)
@@ -217,26 +186,7 @@ namespace AGS.Editor
 					return component;
 				}
 			}
-            // TODO: should we really throw here? Perhaps better throw in the caller's code where applicable?
 			throw new AGSEditorException("No component found that implements " + interfaceType.Name);
 		}
-
-        /// <summary>
-        /// Searches for the Editor's component of the given type and returns its instance,
-        /// or null if one does not exist.
-        /// </summary>
-        /// <typeparam name="T"></typeparam>
-        /// <param name="componentType"></param>
-        /// <returns></returns>
-        public T FindComponent<T>()
-            where T : class, IEditorComponent
-        {
-            foreach (IEditorComponent component in _components)
-            {
-                if (component is T)
-                    return component as T;
-            }
-            return null;
-        }
 	}
 }
