@@ -2,25 +2,16 @@
 using System.Collections.Generic;
 using System.IO;
 using System.Text;
-using System.Linq;
 using AGS.Types;
-using System.Windows.Forms;
 
 namespace AGS.Editor.Components
 {
     class AudioComponent : BaseComponentWithFolders<AudioClip, AudioClipFolder>, IProjectTreeSingleClickHandler
     {
-        public const string AUDIO_CACHE_DIRECTORY = "AudioCache";
-        private const string COMPILED_AUDIO_FILENAME_PREFIX = "au";
         private const string COMMAND_ADD_AUDIO = "AddAudioClipCmd";
-        private const string COMMAND_REIMPORT_ALL = "ReimportAllAudioClipCmd";
-        private const string COMMAND_REPLACE_AUDIO_SOURCE_FOLDER = "ReplaceAudioClipSourceFolderCmd";
         private const string COMMAND_PROPERTIES = "PropertiesAudioClip";
         private const string COMMAND_RENAME = "RenameAudioClip";
-        private const string COMMAND_REIMPORT = "ReimportAudioClip";
-        private const string COMMAND_REPLACE = "ReplaceAudioClip";
         private const string COMMAND_DELETE = "DeleteAudioClip";
-        private const string COMMAND_CHANGE_ID = "ChangeAudioID";
         private const string SPEECH_NODE_ID = "DummySpeechNode";
         private const string AUDIO_TYPES_FOLDER_NODE_ID = "AudioTypesFolderNode";
         private const string NODE_ID_PREFIX_CLIP_TYPE = "AudioClipType";
@@ -60,6 +51,7 @@ namespace AGS.Editor.Components
             _iconMappings.Add(AudioClipFileType.MIDI, "AGSAudioClipIconMidi");
             _iconMappings.Add(AudioClipFileType.MOD, "AGSAudioClipIconMod");
 
+            _agsEditor.GetSourceControlFileList += new GetSourceControlFileListHandler(_agsEditor_GetSourceControlFileList);
             _agsEditor.PreCompileGame += new AGSEditor.PreCompileGameHandler(_agsEditor_PreCompileGame);
 
             RecreateDocument();
@@ -80,7 +72,7 @@ namespace AGS.Editor.Components
         private void RecreateDocument()
         {
             _editor = new AudioEditor();
-            _document = new ContentDocument(_editor, "Audio", this, AUDIO_CLIP_TYPE_ICON);
+            _document = new ContentDocument(_editor, "Audio", this, AUDIO_CLIP_TYPE_ICON);             
         }
 
         public override string ComponentID
@@ -88,20 +80,6 @@ namespace AGS.Editor.Components
             get { return ComponentIDs.Audio; }
         }
 
-        private static string GetCacheFileNameWithoutPath(int index, string sourceFileName)
-        {
-            return string.Format("{0}{1:X6}{2}", COMPILED_AUDIO_FILENAME_PREFIX, index, Path.GetExtension(sourceFileName));
-        }
-
-        private static string GetCacheFileName(int index, string sourceFileName)
-        {
-            return Path.Combine(AUDIO_CACHE_DIRECTORY, GetCacheFileNameWithoutPath(index, sourceFileName));
-        }
-        public static string GetCacheFileName(AudioClip clip)
-        {
-            return Path.Combine(AUDIO_CACHE_DIRECTORY, GetCacheFileNameWithoutPath(clip.Index, clip.SourceFileName));
-        }
-
         protected override void ItemCommandClick(string controlID)
         {
             if (controlID == COMMAND_ADD_AUDIO)
@@ -112,14 +90,6 @@ namespace AGS.Editor.Components
                     ImportAudioFiles(selectedFiles);
                 }
             }
-            else if (controlID == COMMAND_REIMPORT_ALL)
-            {
-                CommandForceReimportOfAllAudioClips();
-            }
-            else if (controlID == COMMAND_REPLACE_AUDIO_SOURCE_FOLDER)
-            {
-                CommandReplaceSourceFolderForAudioClips();
-            }
             else if (controlID == COMMAND_RENAME)
             {
                 _guiController.ProjectTree.BeginLabelEdit(this, _rightClickedID);
@@ -129,38 +99,9 @@ namespace AGS.Editor.Components
                 AudioClip clipToDelete = _items[_rightClickedID];
                 if (_guiController.ShowQuestion("Are you sure you want to delete audio '" + clipToDelete.ScriptName + "'?") == System.Windows.Forms.DialogResult.Yes)
                 {
-                    DeleteSingleItem(clipToDelete);
+                    DeleteSingleItem(clipToDelete);                    
                 }
             }
-            else if (controlID == COMMAND_REIMPORT)
-            {
-                AudioClip clipToReimport = _items[_rightClickedID];
-                CommandForceReimportOfAudioClip(clipToReimport);
-            }
-            else if (controlID == COMMAND_REPLACE)
-            {
-                AudioClip clipToReplace = _items[_rightClickedID];
-                ReplaceAudioClipSource(clipToReplace);
-            }
-            else if (controlID == COMMAND_CHANGE_ID)
-            {
-                AudioClip clipClicked = _items[_rightClickedID];
-                int oldNumber = clipClicked.ID;
-                int newNumber = Factory.GUIController.ShowChangeObjectIDDialog("AudioClip", oldNumber, 0, _items.Count - 1);
-                if (newNumber < 0)
-                    return;
-                foreach (var obj in _items)
-                {
-                    if (obj.Value.ID == newNumber)
-                    {
-                        obj.Value.ID = oldNumber;
-                        break;
-                    }
-                }
-                clipClicked.ID = newNumber;
-                GetFlatList().Swap(oldNumber, newNumber);
-                OnItemIDOrNameChanged(clipClicked, false);
-            }
             else if (controlID == SPEECH_NODE_ID)
             {
                 _guiController.ShowMessage("You create voice speech files by placing them in the Speech sub-folder in explorer, and they must have special names corresponding to the line of text that they represent.\n\nPlease look up 'Voice Speech' in the help file for details.", MessageBoxIconType.Information);
@@ -295,11 +236,6 @@ namespace AGS.Editor.Components
             AudioClipTypeTypeConverter.RefreshAudioClipTypeList();
         }
 
-        public override IList<string> GetManagedScriptElements()
-        {
-            return new string[] { "AudioClip", "AudioType" };
-        }
-
         private void ShowPaneForItem(string controlID)
         {
             object itemToEdit = null;
@@ -329,33 +265,6 @@ namespace AGS.Editor.Components
             }
         }
 
-        public override bool ShowItemPaneByName(string name)
-        {
-            IList<AudioClip> audioClips = _agsEditor.CurrentGame.RootAudioClipFolder.GetAllAudioClipsFromAllSubFolders();
-            foreach (AudioClip ac in audioClips)
-            {
-                if (ac.ScriptName == name)
-                {
-                    _guiController.ProjectTree.SelectNode(this, GetNodeID(ac));
-                    ShowPaneForItem(GetNodeID(ac));
-                    return true;
-                }
-            }
-
-            // it can be an AudioType
-            foreach (AudioClipType clipType in _agsEditor.CurrentGame.AudioClipTypes)
-            {
-                if(clipType.ScriptID == name)
-                {
-                    _guiController.ProjectTree.SelectNode(this, GetClipTypeNodeID(clipType));
-                    ShowPaneForItem(GetClipTypeNodeID(clipType));
-                    return true;
-                }
-            }
-
-            return false;
-        }
-
         private void ImportAudioFiles(string[] selectedFiles)
         {
             string lastAddedId = null;
@@ -370,6 +279,10 @@ namespace AGS.Editor.Components
                     parentFolder.Items.Add(newClip);
                     lastAddedId = newClip.ScriptName;
                 }
+                else
+                {
+                    _guiController.ShowMessage("The file '" + fileName + "' could not be imported. The file type was not recognised.", MessageBoxIconType.Warning);
+                }
             }
 
             if (lastAddedId != null)
@@ -379,90 +292,39 @@ namespace AGS.Editor.Components
             }
         }
 
-        private AudioClip SetAudioClipSourceFile(AudioClip clip, string fullSourceFileName)
+        private string GetNodeIDForAudioClip(AudioClip clip)
         {
-            if (string.IsNullOrEmpty(fullSourceFileName))
-            {
-                return null;
-            }
-
-            if(!File.Exists(fullSourceFileName))
-            {
-                throw new FileNotFoundException("Source file doesn't exist.");
-            }
-            else
-            {
-                var clipSourceFileInfo = new FileInfo(fullSourceFileName);
-                if(clipSourceFileInfo.Length == 0) throw new FileLoadException("New source file is empty.");
-            }
-
-            string fileExtension = Path.GetExtension(fullSourceFileName).ToLower();
-            if (!_fileTypeMappings.ContainsKey(fileExtension))
-            {
-                throw new InvalidOperationException("Source file is of unsupported type.");
-            }
-
-            string sourceFileName = Utilities.GetRelativeToProjectPath(fullSourceFileName);
-            string newCacheFileName = GetCacheFileName(clip.Index, sourceFileName);
-            DateTime lastModifiedDate = File.GetLastWriteTimeUtc(sourceFileName);
-
-            string previousCacheFileName = clip.CacheFileName;
-
-            Utilities.CopyFileAndSetDestinationWritable(sourceFileName, newCacheFileName);
-            if (!string.IsNullOrEmpty(previousCacheFileName) && previousCacheFileName != newCacheFileName) 
-                Utilities.TryDeleteFile(previousCacheFileName); // in case extension is different
-
-            Utilities.TryDeleteFile(Path.Combine(AGSEditor.OUTPUT_DIRECTORY,
-                Path.Combine(AGSEditor.DATA_OUTPUT_DIRECTORY, AGSEditor.AUDIO_VOX_FILE_NAME)));
-
-            clip.FileType = _fileTypeMappings[fileExtension];
-            clip.FileLastModifiedDate = lastModifiedDate;
-            clip.SourceFileName = sourceFileName;
-            clip.CacheFileName = newCacheFileName;
-            _agsEditor.CurrentGame.FilesAddedOrRemoved = true;
-            return clip;
+            return ITEM_COMMAND_PREFIX + clip.ScriptName;
         }
 
-
         private AudioClip CreateAudioClipForFile(string sourceFileName)
         {
-            string newScriptName = EnsureScriptNameIsUnique(
-                Path.GetFileNameWithoutExtension(sourceFileName));
-            AudioClip newClip = new AudioClip(newScriptName, _agsEditor.CurrentGame.GetNextAudioIndex());
-            newClip.ID = _agsEditor.CurrentGame.RootAudioClipFolder.GetAllItemsCount();
-
-            try
+            string fileExtension = Path.GetExtension(sourceFileName).ToLower();
+            if (_fileTypeMappings.ContainsKey(fileExtension))
             {
-                SetAudioClipSourceFile(newClip, sourceFileName);
+                string newScriptName = EnsureScriptNameIsUnique(Path.GetFileNameWithoutExtension(sourceFileName));
+                AudioClip newClip = new AudioClip(newScriptName, _agsEditor.CurrentGame.GetNextAudioIndex());
+                newClip.SourceFileName = sourceFileName;
+                newClip.FileType = _fileTypeMappings[fileExtension];
+                newClip.FileLastModifiedDate = File.GetLastWriteTimeUtc(sourceFileName);
+                Utilities.CopyFileAndSetDestinationWritable(sourceFileName, newClip.CacheFileName);
+                Utilities.DeleteFileIfExists(AGSEditor.AUDIO_VOX_FILE_NAME);
+                _agsEditor.CurrentGame.FilesAddedOrRemoved = true;
+                return newClip;
             }
-            catch (Exception ex)
-            {
-                _guiController.ShowError("Failed to create audio clip from " + sourceFileName + ".", ex, MessageBoxIcon.Warning);
-                return null;
-            }
-
-            return newClip;
+            return null;
         }
 
-        private string EnsureScriptNameIsUnique(string nameToTry, int truncateToLength = Int32.MaxValue)
+        private string EnsureScriptNameIsUnique(string nameToTry)
         {
             nameToTry = AGS.Types.Utilities.RemoveInvalidCharactersFromScriptName(nameToTry);
-            nameToTry = "a" + Char.ToUpperInvariant(nameToTry[0]) + nameToTry.Substring(1);
-            string tryThisTime = nameToTry.Length > truncateToLength ?
-                nameToTry.Substring(0, truncateToLength) : nameToTry;
+            nameToTry = "a" + Char.ToUpper(nameToTry[0]) + nameToTry.Substring(1);
+            string tryThisTime = nameToTry;
             int suffix = 0;
             while (_agsEditor.CurrentGame.IsScriptNameAlreadyUsed(tryThisTime, null))
             {
                 suffix++;
-                string suffixStr = suffix.ToString();
-                if (nameToTry.Length + suffixStr.Length > truncateToLength)
-                {
-                    tryThisTime = nameToTry.Substring(0, truncateToLength - suffixStr.Length) + suffix;
-                }
-                else
-                {
-                    tryThisTime = nameToTry + suffix;
-                }
+                tryThisTime = nameToTry + suffix;
             }
             return tryThisTime;
         }
@@ -507,14 +369,14 @@ namespace AGS.Editor.Components
                 }
                 else
                 {
-                    _agsEditor.CurrentGame.Settings.PlaySoundOnScore = AudioClip.FixedIndexNoValue;
+                    _agsEditor.CurrentGame.Settings.PlaySoundOnScore = 0;
                 }
             }
         }
 
         private void UpdateViewFrameSounds(IList<AudioClip> allAudio, ViewFolder views)
         {
-            foreach (AGS.Types.View view in views.Views)
+            foreach (View view in views.Views)
             {
                 foreach (ViewLoop loop in view.Loops)
                 {
@@ -529,7 +391,7 @@ namespace AGS.Editor.Components
                             }
                             else
                             {
-                                frame.Sound = AudioClip.FixedIndexNoValue;
+                                frame.Sound = 0;
                             }
                         }
                     }
@@ -579,6 +441,18 @@ namespace AGS.Editor.Components
             }
         }
 
+        private void _agsEditor_GetSourceControlFileList(IList<string> fileNames)
+        {
+            if (_agsEditor.CurrentGame.Settings.BinaryFilesInSourceControl)
+            {
+                string audioFolderPath = Path.Combine(_agsEditor.GameDirectory, AudioClip.AUDIO_CACHE_DIRECTORY);
+                foreach (AudioClip clip in _agsEditor.CurrentGame.RootAudioClipFolder.GetAllAudioClipsFromAllSubFolders())
+                {
+                    fileNames.Add(Path.Combine(audioFolderPath, clip.CacheFileName));
+                }
+            }
+        }
+
         private void SetActualAudioClipProperties(AudioClip clip, int inheritedVolume, bool inheritedRepeat, AudioClipPriority inheritedPriority)
         {
             if (clip.DefaultPriority == AudioClipPriority.Inherit)
@@ -609,152 +483,6 @@ namespace AGS.Editor.Components
             }
         }
 
-        private void CommandForceReimportOfAudioClip(AudioClip clip)
-        {
-            if (!ForceReimportOfAudioClip(clip))
-            {
-                _guiController.ShowMessage("Failed to reimport Audio Clip " + clip.ScriptName + ".", MessageBoxIconType.Warning);
-            }
-        }
-
-        private bool ForceReimportOfAudioClip(string sourceFileName, string cacheFileName)
-        {
-            if (File.Exists(sourceFileName) && !string.IsNullOrEmpty(cacheFileName))
-            {
-                return Utilities.SafeCopyFileOverwrite(sourceFileName, cacheFileName, true);
-            }
-            return false;
-        }
-
-        private bool ForceReimportOfAudioClip(AudioClip clip)
-        {
-            return ForceReimportOfAudioClip(clip.SourceFileName, clip.CacheFileName);
-        }
-
-        private void DoForceReimportOfAudioClips(IEnumerable<AudioClip> audioClips, IWorkProgress progress, out List<AudioClip> failedClips)
-        {
-            failedClips = new List<AudioClip>();
-            progress.Total = audioClips.Count();
-            progress.Current = 0;
-            foreach (AudioClip clip in audioClips)
-            {
-                if (!ForceReimportOfAudioClip(clip))
-                {
-                    failedClips.Add(clip);
-                }
-                progress.Current++;
-            }
-        }
-
-        private void CommandForceReimportOfAllAudioClips()
-        {
-            List<AudioClip> failedClips = new List<AudioClip>();
-            IEnumerable<AudioClip> allAudioClips = _agsEditor.CurrentGame.RootAudioClipFolder.AllItemsFlat;
-
-            try
-            {
-                BusyDialog.Show("Please wait while the Audio Clipes are reimported ...",
-                    new BusyDialog.ProcessingHandler(
-                        (IWorkProgress progress, object o) => {
-                            DoForceReimportOfAudioClips(allAudioClips, progress, out failedClips);
-                            return null;
-                        }), null);
-            }
-            catch (Exception e)
-            {
-                Factory.GUIController.ShowError(
-                    "The reimport of all audio clips was interrupted by error.", e,
-                    MessageBoxIcon.Error);
-                return;
-            }
-
-            Factory.GUIController.ClearOutputPanel();
-            if (!failedClips.Any()) return; // success!
-
-            CompileMessages errors = new CompileMessages();
-            errors.AddRange(failedClips.
-                Select(ac => new CompileWarning("Failed audio clip reimport of " + ac.ScriptName, ac.SourceFileName, 0)).
-                ToList<CompileMessage>());
-
-            Factory.GUIController.ShowOutputPanel(errors);
-        }
-
-        public void ReplaceAudioClipSource(AudioClip clip)
-        {
-            string dir = Path.GetDirectoryName(clip.SourceFileName);
-            if (!Directory.Exists(dir)) dir = Factory.AGSEditor.CurrentGame.DirectoryPath;
-            string selectedFile = _guiController.ShowOpenFileDialog("Select audio to add", AUDIO_FILES_FILTER, dir);
-            if (string.IsNullOrEmpty(selectedFile)) return; // clicked cancel in File Dialog, no need to report anything
-
-            try
-            {
-                clip = SetAudioClipSourceFile(clip, selectedFile);
-            }
-            catch (Exception ex)
-            {
-                Factory.GUIController.ShowError(
-                     "Failed to replace audio clip source file.", ex,
-                    MessageBoxIcon.Error);
-                return;
-            }
-
-            if (_editor.SelectedItem is AudioClip)
-            {
-                if (_editor.SelectedItem.GetHashCode() == clip.GetHashCode())
-                {
-                    _editor.SelectedItem = clip;
-                    Factory.GUIController.RefreshPropertyGrid();
-                }
-            }
-        }
-
-        private void CommandReplaceSourceFolderForAudioClips()
-        {
-            var allAudioClips = _agsEditor.CurrentGame.RootAudioClipFolder.AllItemsFlat;
-            string firstFoundSourceFile = null;
-            AudioClip foundClip = allAudioClips.Where(s => !string.IsNullOrEmpty(s.SourceFileName)).FirstOrDefault();
-            if (foundClip != null)
-                firstFoundSourceFile = foundClip.SourceFileName;
-
-            if (string.IsNullOrEmpty(firstFoundSourceFile))
-            {
-                Factory.GUIController.ShowMessage("None of the audio clips has a source filename.", MessageBoxIcon.Warning);
-                return;
-            }
-
-            string parentDir = Path.GetDirectoryName(firstFoundSourceFile);
-            var replaceDirs = ReplaceFolderDialog.Show("Replace audio clip(s) source path",
-                "Please choose which part of the parent path should be replaced and provide a replacement. Relative paths will be assumed relative to your game's project folder.",
-                parentDir, parentDir, Factory.AGSEditor.CurrentGame.DirectoryPath);
-
-            if (replaceDirs == null || replaceDirs.Item1 == replaceDirs.Item2)
-                return;
-
-            int itemCount = 0;
-            foreach (var clip in allAudioClips)
-            {
-                if (string.IsNullOrEmpty(clip.SourceFileName))
-                    continue;
-
-                string newPath;
-                if (Utilities.ReplacePathBaseProjectRelative(clip.SourceFileName, replaceDirs.Item1, replaceDirs.Item2, out newPath))
-                {
-                    clip.SourceFileName = newPath;
-                    itemCount++;
-                }
-            }
-
-            if (itemCount > 0)
-            {
-                Factory.GUIController.ShowMessage($"{itemCount} audio clip(s) had their source paths updated.", MessageBoxIcon.Information);
-                Factory.GUIController.RefreshPropertyGrid();
-            }
-            else
-            {
-                Factory.GUIController.ShowMessage($"No audio clips with the matching old paths found, no changes were made.", MessageBoxIcon.Information);
-            }
-        }
-
         private void AddAudioClipToListIfFileNeedsToBeCopiedFromSource(AudioClip clip, PreCompileGameEventArgs evArgs, List<AudioClip> filesToCopy, List<string> fileNamesToUpdate)
         {
             string compiledFileName = clip.CacheFileName;
@@ -824,7 +552,7 @@ namespace AGS.Editor.Components
                 }
             }
 
-            _agsEditor.CurrentGame.UpdateAudioClipMap();
+            _agsEditor.CurrentGame.UpdateCachedAudioClipList();
         }
 
         private void ProjectTree_OnAfterLabelEdit(string commandID, ProjectTreeItem treeItem)
@@ -856,15 +584,6 @@ namespace AGS.Editor.Components
             return _iconMappings[clip.FileType];
         }
 
-        private void OnItemIDOrNameChanged(AudioClip item, bool name_only)
-        {
-            if (name_only)
-                ChangeItemLabel(GetNodeID(item), GetNodeLabel(item));
-            else
-                RePopulateTreeView(GetNodeID(item)); // currently this is the only way to update tree item ids
-            AudioClipTypeConverter.RefreshAudioClipList();
-        }
-
         public override void PropertyChanged(string propertyName, object oldValue)
         {
             if (propertyName == "ScriptName")
@@ -877,16 +596,21 @@ namespace AGS.Editor.Components
                 }
                 else
                 {
-                    RePopulateTreeView(GetNodeID(itemBeingEdited));
+                    RePopulateTreeView(GetNodeIDForAudioClip(itemBeingEdited));
                     AudioClipTypeConverter.RefreshAudioClipList();
                 }
             }
             else if (propertyName == "Name")
             {
-                string nodeId = (_editor.SelectedItem is AudioClipFolder) ?
-                    GetNodeIDForFolder(_editor.SelectedItem as AudioClipFolder) :
-                    AUDIO_TYPES_FOLDER_NODE_ID;
-                RePopulateTreeView(nodeId);
+                RePopulateTreeView();
+                if (_editor.SelectedItem is AudioClipFolder)
+                {
+                    _guiController.ProjectTree.SelectNode(this, GetNodeIDForFolder((AudioClipFolder)_editor.SelectedItem));
+                }
+                else
+                {
+                    _guiController.ProjectTree.SelectNode(this, AUDIO_TYPES_FOLDER_NODE_ID);
+                }
             }
         }
 
@@ -910,13 +634,9 @@ namespace AGS.Editor.Components
             }
             else if (!IsFolderNode(controlID))
             {
-                menu.Add(new MenuCommand(COMMAND_CHANGE_ID, "Change Clip ID", null));
                 menu.Add(new MenuCommand(COMMAND_RENAME, "Rename", null));
                 menu.Add(new MenuCommand(COMMAND_DELETE, "Delete", null));
                 menu.Add(MenuCommand.Separator);
-                menu.Add(new MenuCommand(COMMAND_REPLACE, "Replace Source File", null));
-                menu.Add(new MenuCommand(COMMAND_REIMPORT, "Force Reimport", null));
-                menu.Add(MenuCommand.Separator);
                 menu.Add(new MenuCommand(COMMAND_PROPERTIES, "Properties", null));
             }
             return menu;
@@ -927,33 +647,13 @@ namespace AGS.Editor.Components
             return _agsEditor.CurrentGame.RootAudioClipFolder;
         }
 
-        protected override IList<AudioClip> GetFlatList()
-        {
-            return _agsEditor.CurrentGame.AudioClipFlatList;
-        }
-
-        private string GetClipTypeNodeID(AudioClipType clipType)
-        {
-            return NODE_ID_PREFIX_CLIP_TYPE + clipType.TypeID;
-        }
-
-        private string GetNodeID(AudioClip clip)
-        {
-            return ITEM_COMMAND_PREFIX + clip.ScriptName;
-        }
-
-        private string GetNodeLabel(AudioClip item)
-        {
-            return item.ID.ToString() + ": " + item.ScriptName;
-        }
-
         protected override ProjectTreeItem CreateTreeItemForItem(AudioClip item)
         {
-            ProjectTreeItem treeItem = (ProjectTreeItem)_guiController.ProjectTree.AddTreeLeaf(this, GetNodeID(item),
-                GetNodeLabel(item), GetIconKeyForAudioClip(item));
+            string nodeID = GetNodeIDForAudioClip(item);
+            ProjectTreeItem treeItem = (ProjectTreeItem)_guiController.ProjectTree.AddTreeLeaf(this, nodeID, item.ScriptName, GetIconKeyForAudioClip(item));
             treeItem.AllowLabelEdit = true;
             treeItem.LabelTextProperty = item.GetType().GetProperty("ScriptName");
-            treeItem.LabelTextDescriptionProperty = item.GetType().GetProperty("NameAndID");
+            treeItem.LabelTextDescriptionProperty = item.GetType().GetProperty("ScriptName");
             treeItem.LabelTextDataSource = item;
             return treeItem;
         }
@@ -965,9 +665,6 @@ namespace AGS.Editor.Components
 
         protected override void AddExtraCommandsToFolderContextMenu(string controlID, IList<MenuCommand> menu)
         {
-            menu.Add(MenuCommand.Separator);
-            menu.Add(new MenuCommand(COMMAND_REPLACE_AUDIO_SOURCE_FOLDER, "Replace source paths for audio clips...", null));
-            menu.Add(new MenuCommand(COMMAND_REIMPORT_ALL, "Force reimport all file(s)", null));
             menu.Add(MenuCommand.Separator);
             menu.Add(new MenuCommand(COMMAND_PROPERTIES, "Properties", null));
         }
@@ -995,7 +692,7 @@ namespace AGS.Editor.Components
 
         private string AddTreeNodeForAudioClipType(AudioClipType clipType)
         {
-            string newNodeID = GetClipTypeNodeID(clipType);
+            string newNodeID = NODE_ID_PREFIX_CLIP_TYPE + clipType.TypeID;
             ProjectTreeItem treeItem = (ProjectTreeItem)_guiController.ProjectTree.AddTreeLeaf(this, newNodeID, clipType.Name, AUDIO_CLIP_TYPE_ICON);
             treeItem.AllowLabelEdit = true;
             treeItem.LabelTextProperty = clipType.GetType().GetProperty("Name");
@@ -1011,22 +708,8 @@ namespace AGS.Editor.Components
 
         protected override void DeleteResourcesUsedByItem(AudioClip item)
         {
-            DeleteAudioClip(item);
-        }
-
-        private void DeleteAudioClip(AudioClip clip)
-        {
-            int removingID = clip.ID;
-            foreach (AudioClip item in _agsEditor.CurrentGame.RootAudioClipFolder.AllItemsFlat)
-            {
-                if (item.ID > removingID)
-                {
-                    item.ID--;
-                }
-            }
-
-            DeleteResourcesForAudioClip(clip);
-            AudioClipTypeConverter.SetAudioClipList(_agsEditor.CurrentGame.RootAudioClipFolder.GetAllAudioClipsFromAllSubFolders());
+            DeleteResourcesForAudioClip(item);
+            AudioClipTypeConverter.SetAudioClipList(_agsEditor.CurrentGame.RootAudioClipFolder.GetAllAudioClipsFromAllSubFolders());                    
         }
 
         private void DeleteResourcesForAudioClip(AudioClip clipToDelete)
@@ -1047,11 +730,9 @@ namespace AGS.Editor.Components
                 }
                 filesToDelete.Add(clip.CacheFileName);
             }
-            _agsEditor.DeleteFileOnDisk(filesToDelete.ToArray());
+            _agsEditor.DeleteFileOnDiskAndSourceControl(filesToDelete.ToArray());
             _agsEditor.CurrentGame.FilesAddedOrRemoved = true;
-            Utilities.TryDeleteFile(Path.Combine(AGSEditor.OUTPUT_DIRECTORY,
-                Path.Combine(AGSEditor.DATA_OUTPUT_DIRECTORY, AGSEditor.AUDIO_VOX_FILE_NAME)));
+            Utilities.DeleteFileIfExists(AGSEditor.AUDIO_VOX_FILE_NAME);
         }
-
     }
 }
