@@ -2,9 +2,7 @@ using System;
 using System.Collections.Generic;
 using System.Drawing;
 using System.IO;
-using System.Linq;
 using System.Text;
-using System.Text.RegularExpressions;
 using System.Windows.Forms;
 using System.Xml;
 using AGS.Types;
@@ -26,7 +24,6 @@ namespace AGS.Editor.Components
         private const int TRANSLATION_BLOCK_TRANSLATION_DATA = 1;
         private const int TRANSLATION_BLOCK_GAME_ID = 2;
         private const int TRANSLATION_BLOCK_OPTIONS = 3;
-        private const string TRANSLATION_BLOCK_STROPTIONS = "ext_sopts";
         private const int TRANSLATION_BLOCK_END_OF_FILE = -1;
 
 //        private Dictionary<AGS.Types.Font, ContentDocument> _documents;
@@ -64,7 +61,7 @@ namespace AGS.Editor.Components
                 attempt++;
                 newFileName = "New Translation" + ((attempt == 1) ? "" : attempt.ToString());
             }
-            while (_agsEditor.CurrentGame.Translations.FirstOrDefault(t => t.Name == newFileName) != null);
+            while (File.Exists(newFileName + Translation.TRANSLATION_SOURCE_FILE_EXTENSION));
             return newFileName;
         }
 
@@ -79,112 +76,64 @@ namespace AGS.Editor.Components
             {
                 if (File.Exists(translation.FileName))
                 {
-                    string compiledPath = Path.Combine(AGSEditor.OUTPUT_DIRECTORY,
-                        Path.Combine(AGSEditor.DATA_OUTPUT_DIRECTORY, translation.CompiledFileName));
+                    string compiledPath = Path.Combine(AGSEditor.OUTPUT_DIRECTORY, translation.CompiledFileName);
 
                     if ((evArgs.ForceRebuild) ||
 						(Utilities.DoesFileNeedRecompile(translation.FileName, compiledPath)))
                     {
-                        try
-                        {
-                            CompileTranslation(translation, evArgs.Errors);
-                        }
-                        catch (Exception e)
-                        {
-                            evArgs.Errors.Add(new CompileError(string.Format("Translation '{0}' compiled with errors: \n{1}",
-                                translation.FileName, e.Message)));
-                        }
+                        CompileTranslation(translation, evArgs.Errors);
                     }
                 }
             }
         }
 
-        // "Avis Durgan" in ASCII
-        private byte[] EncryptKey = Encoding.ASCII.GetBytes("Avis Durgan");
-
-        private byte[] EncryptStringToBytes(string text, Encoding encoding)
+        private string ConvertEscapedCharacters(string scriptStyleString)
         {
-            var bytes = encoding.GetBytes(text);
-            for (int i = 0, key = 0; i < bytes.Length; ++i)
-            {
-                bytes[i] += EncryptKey[key++];
-                if (key > 10)
-                    key = 0;
-            }
-            return bytes;
-        }
-
-        private void WriteString(BinaryWriter bw, string text, Encoding encoding)
-        {
-            var bytes = EncryptStringToBytes(text, encoding);
-            bw.Write(bytes.Length);
-            bw.Write(bytes);
-        }
-
-        /// <summary>
-        /// This double escapes an escaped '[' character (old-style linebreak,
-        /// which must be escaped by user if they want a literal '[' in text).
-        /// This is required before doing standard unescaping for this line.
-        /// </summary>
-        private string PreprocessLineForOldStyleLinebreaks(string line)
-        {
-            return line.Replace("\\[", "\\\\[");
+            // The translation source has \" and \\, but the engine expects " and \
+            return scriptStyleString.Replace("\\\"", "\"").Replace("\\\\", "\\");
         }
 
         private void CompileTranslation(Translation translation, CompileMessages errors)
         {
-            var load_errors = translation.TryLoadData();
-            errors.AddRange(load_errors);
-            if (load_errors.HasErrors)
+            translation.LoadData();
+
+            if (translation.TranslatedLines.Count < 1)
+            {
+                errors.Add(new CompileError("Translation " + translation.FileName + " appears to be empty. You must update the source before compiling.", translation.FileName, 1));
                 return;
+            }
 
-            string tempFile = Path.GetTempFileName();
-            Encoding textEncoding = translation.Encoding;
+            string compiledFile = Path.Combine(AGSEditor.OUTPUT_DIRECTORY, translation.CompiledFileName);
+            bool foundTranslatedLine = false;
 
-            using (BinaryWriter bw = new BinaryWriter(new FileStream(tempFile, FileMode.Create, FileAccess.Write)))
+            using (BinaryWriter bw = new BinaryWriter(new FileStream(compiledFile, FileMode.Create, FileAccess.Write)))
             {
                 bw.Write(Encoding.ASCII.GetBytes(COMPILED_TRANSLATION_FILE_SIGNATURE));
                 bw.Write(TRANSLATION_BLOCK_GAME_ID);
-                byte[] gameName = EncryptStringToBytes(_agsEditor.CurrentGame.Settings.GameName, _agsEditor.CurrentGame.TextEncoding);
-                bw.Write(gameName.Length + 4 + 4);
+                byte[] gameName = Factory.NativeProxy.TransformStringToBytes(_agsEditor.CurrentGame.Settings.GameName);
+                bw.Write(gameName.Length + 4);
                 bw.Write(_agsEditor.CurrentGame.Settings.UniqueID);
-                bw.Write(gameName.Length);
                 bw.Write(gameName);
                 bw.Write(TRANSLATION_BLOCK_TRANSLATION_DATA);
                 long offsetOfBlockSize = bw.BaseStream.Position;
-                bw.Write((int)0); // placeholder for block size, will be filled later
+                bw.Write((int)0);
                 foreach (string line in translation.TranslatedLines.Keys)
                 {
                     if (translation.TranslatedLines[line].Length > 0)
                     {
-                        string src_line = PreprocessLineForOldStyleLinebreaks(line);
-                        string trs_line = PreprocessLineForOldStyleLinebreaks(translation.TranslatedLines[line]);
-                        WriteString(bw, Regex.Unescape(src_line), textEncoding);
-                        WriteString(bw, Regex.Unescape(trs_line), textEncoding);
+                        foundTranslatedLine = true;
+                        bw.Write(Factory.NativeProxy.TransformStringToBytes(ConvertEscapedCharacters(line)));
+                        bw.Write(Factory.NativeProxy.TransformStringToBytes(ConvertEscapedCharacters(translation.TranslatedLines[line])));
                     }
                 }
-                WriteString(bw, string.Empty, textEncoding);
-                WriteString(bw, string.Empty, textEncoding);
+                bw.Write(Factory.NativeProxy.TransformStringToBytes(string.Empty));
+                bw.Write(Factory.NativeProxy.TransformStringToBytes(string.Empty));
                 long mainBlockSize = (bw.BaseStream.Position - offsetOfBlockSize) - 4;
                 bw.Write(TRANSLATION_BLOCK_OPTIONS);
                 bw.Write((int)12);
                 bw.Write(translation.NormalFont ?? -1);
                 bw.Write(translation.SpeechFont ?? -1);
                 bw.Write((translation.RightToLeftText == true) ? 2 : ((translation.RightToLeftText == false) ? 1 : -1));
-
-                bw.Write((int)0); // required for compatibility
-                DataFileWriter.WriteString(TRANSLATION_BLOCK_STROPTIONS, 16, bw);
-                var data_len_pos = bw.BaseStream.Position;
-                bw.Write((long)0); // data length placeholder
-                bw.Write((int)1); // size of key/value table
-                DataFileWriter.FilePutString("encoding", bw);
-                DataFileWriter.FilePutString(translation.EncodingHint, bw);
-                var end_pos = bw.BaseStream.Position;
-                var data_len = end_pos - data_len_pos - 8;
-                bw.Seek((int)data_len_pos, SeekOrigin.Begin);
-                bw.Write(data_len);
-                bw.Seek((int)end_pos, SeekOrigin.Begin);
-
                 bw.Write(TRANSLATION_BLOCK_END_OF_FILE);
                 bw.Write((int)0);
                 bw.Seek((int)offsetOfBlockSize, SeekOrigin.Begin);
@@ -192,24 +141,18 @@ namespace AGS.Editor.Components
                 bw.Close();
             }
 
-            string destFile = Path.Combine(AGSEditor.OUTPUT_DIRECTORY,
-                Path.Combine(AGSEditor.DATA_OUTPUT_DIRECTORY, translation.CompiledFileName));
-            Utilities.ExecuteOrError(() =>
+            if (!foundTranslatedLine)
             {
-                Utilities.TryDeleteFile(destFile);
-                File.Move(tempFile, destFile);
-            }, $"Failed to replace an old file {destFile}", errors);
+                errors.Add(new CompileError("Translation " + translation.FileName + " did not appear to have any translated lines. Make sure you translate some text before compiling the translation.", translation.FileName, 1));
+                File.Delete(compiledFile);
+            }
         }
 
-        private object UpdateTranslationsProcess(IWorkProgress progress, object translationList)
+        private object UpdateTranslationsProcess(object translationList)
         {
             List<Translation> translations = (List<Translation>)translationList;
             TranslationGenerator generator = new TranslationGenerator();
-            CompileMessages messages = generator.CreateTranslationList(_agsEditor.CurrentGame);
-
-            if (messages.HasErrors)
-                return messages; // abort for avoiding corrupting translations
-
+            CompileMessages errors = generator.CreateTranslationList(_agsEditor.CurrentGame);
             foreach (string line in generator.LinesForTranslation)
             {
                 foreach (Translation translation in translations)
@@ -231,49 +174,22 @@ namespace AGS.Editor.Components
                     }
                 }
             }
-            return messages;
+            return errors;
         }
 
         private void DoTranslationUpdate(IList<Translation> translations)
         {
             _agsEditor.SaveGameFiles();
-
-            List<Translation> translationsToUpdate = new List<Translation>();
-            // reload current translations, in case the trs files were modified externally
-            CompileMessages messages = new CompileMessages();
-            foreach (var translation in translations)
-            {
-                CompileMessages errors = null;
-                if (File.Exists(translation.FileName))
-                {
-                    errors = translation.TryLoadData();
-                    messages.AddRange(errors);
-                }
-                if (errors == null || !errors.HasErrors)
-                    translationsToUpdate.Add(translation);
-            }
-
-            if (translationsToUpdate.Count > 0)
-            {
-                messages.AddRange((CompileMessages)BusyDialog.Show("Please wait while the translation(s) are updated...",
-                    new BusyDialog.ProcessingHandler(UpdateTranslationsProcess), translationsToUpdate));
-            }
-            _guiController.ShowOutputPanel(messages);
-            if (!messages.HasErrors)
-                _guiController.ShowMessage("Translation(s) updated.", MessageBoxIcon.Information);
-            else
-                _guiController.ShowMessage("Translation(s) update failed. Check the output window for details.", MessageBoxIcon.Error);
+            CompileMessages errors = (CompileMessages)BusyDialog.Show("Please wait while the translation(s) are updated...", new BusyDialog.ProcessingHandler(UpdateTranslationsProcess), translations);
+            _guiController.ShowOutputPanel(errors);
+            _guiController.ShowMessage("Translation(s) updated.", MessageBoxIcon.Information);
         }
 
         private void UpdateAllTranslationsWithNewDefaultText(Dictionary<string, string> textChanges, CompileMessages errors)
         {
             foreach (Translation otherTranslation in _agsEditor.CurrentGame.Translations)
             {
-                var load_errors = otherTranslation.TryLoadData();
-                errors.AddRange(load_errors);
-                if (load_errors.HasErrors)
-                    continue; // failure
-
+                otherTranslation.LoadData();
                 Dictionary<string, string> newTranslation = new Dictionary<string, string>();
 
                 foreach (string sourceLine in otherTranslation.TranslatedLines.Keys)
@@ -317,7 +233,7 @@ namespace AGS.Editor.Components
             }
         }
 
-        private object ReplaceGameTextWithTranslationProcess(IWorkProgress progress, object translationAsObj)
+        private object ReplaceGameTextWithTranslationProcess(object translationAsObj)
         {
             Translation translation = (Translation)translationAsObj;
             CompileMessages errors = TextImporter.ReplaceAllGameText(_agsEditor.CurrentGame, translation);
@@ -351,17 +267,9 @@ namespace AGS.Editor.Components
             {
                 return;
             }
-
-            CompileMessages errors = translation.TryLoadData();
-            if (errors.HasErrors)
-            {
-                _guiController.ShowOutputPanel(errors);
-                _guiController.ShowMessage("There were errors when loading the translation. Please consult the output window for details.", MessageBoxIcon.Error);
-                return;
-            }
-
-            errors.AddRange((CompileMessages)BusyDialog.Show("Please wait while the game text is replaced...",
-                new BusyDialog.ProcessingHandler(ReplaceGameTextWithTranslationProcess), translation));
+            
+            translation.LoadData();
+            CompileMessages errors = (CompileMessages)BusyDialog.Show("Please wait while the game text is replaced...", new BusyDialog.ProcessingHandler(ReplaceGameTextWithTranslationProcess), translation);
             _guiController.ShowOutputPanel(errors);
             Factory.Events.OnRefreshAllComponentsFromGame();
             _agsEditor.SaveGameFiles(); 
@@ -388,8 +296,8 @@ namespace AGS.Editor.Components
                 // Create a dummy placeholder file
                 StreamWriter sw = new StreamWriter(newItem.FileName);
                 sw.Close();
-                _guiController.ShowOutputPanel(newItem.TryLoadData());
-
+                newItem.LoadData();
+                
                 string newNodeID = "Trl" + (items.Count - 1);
                 _guiController.ProjectTree.StartFromNode(this, TOP_LEVEL_COMMAND_ID);
                 AddTreeLeafForTranslation(newNodeID, newItem);
@@ -422,18 +330,10 @@ namespace AGS.Editor.Components
             else if (controlID == COMMAND_COMPILE)
             {
                 CompileMessages errors = new CompileMessages();
-                try
-                {
-                    CompileTranslation(_itemRightClicked, errors);
-                }
-                catch (Exception e)
-                {
-                    errors.Add(new CompileError(e.Message));
-                }
+                CompileTranslation(_itemRightClicked, errors);
                 if (errors.Count > 0)
                 {
-                    _guiController.ShowMessage(string.Format("Translation compiled with errors: \n\n{0}",
-                        errors[0].Message), MessageBoxIcon.Warning);
+                    _guiController.ShowMessage(errors[0].Message, MessageBoxIcon.Warning);
                 }
                 else
                 {
@@ -455,10 +355,9 @@ namespace AGS.Editor.Components
 
                     if (File.Exists(_itemRightClicked.FileName))
                     {
-						_agsEditor.DeleteFileOnDisk(_itemRightClicked.FileName);
+						_agsEditor.DeleteFileOnDiskAndSourceControl(_itemRightClicked.FileName);
                     }
                     RePopulateTreeView();
-                    TranslationListTypeConverter.SetTranslationsList(_agsEditor.CurrentGame.Translations);
                 }
             }
             else
@@ -539,7 +438,6 @@ namespace AGS.Editor.Components
             _documents.Clear();
             */
             RePopulateTreeView();
-            TranslationListTypeConverter.SetTranslationsList(_agsEditor.CurrentGame.Translations);
         }
 
         private void _timer_Tick(object sender, EventArgs e)
@@ -559,6 +457,11 @@ namespace AGS.Editor.Components
                 string sourcePath = Path.GetFullPath(_oldNameBeforeRename + Translation.TRANSLATION_SOURCE_FILE_EXTENSION);
                 string destPath = Path.GetFullPath(translation.FileName);
 
+                if (_agsEditor.SourceControlProvider.IsFileUnderSourceControl(sourcePath))
+                {
+                    _agsEditor.SourceControlProvider.RenameFile(sourcePath, destPath);
+                }
+
                 File.Move(sourcePath, destPath);
 				_agsEditor.CurrentGame.FilesAddedOrRemoved = true;
 
@@ -572,7 +475,6 @@ namespace AGS.Editor.Components
                     }
                 }
             }
-            TranslationListTypeConverter.SetTranslationsList(_agsEditor.CurrentGame.Translations);
         }
 
         private void ProjectTree_OnAfterLabelEdit(string commandID, ProjectTreeItem treeItem)
