@@ -25,34 +25,27 @@ namespace AGS.Editor
         public event ActiveDocumentChangedHandler OnActiveDocumentChanged;
         public event EventHandler OnMainWindowActivated;
 
-        private TabbedDocumentManager.ActiveDocumentChangeHandler _activeDocumentChanged;
-        private TabbedDocumentManager.ActiveDocumentChangeHandler _activeDocumentChanging;
-
         private Dictionary<string, object> _propertyObjectList = null;
         private bool _ignorePropertyListChange = false;
-        private bool _ignoreSelectObjectInList = false;
-        private bool _suspendDrawing = false;
-        private List<DockContent> _dockPanes = new List<DockContent>();
+		//private int _splitterXtoSet = 0;
+		//private int _splitterYtoSet = 0;
+		private bool _suspendDrawing = false;
         private WindowsLayoutManager _layoutManager;
 
         public frmMain()
         {
             InitializeComponent();
-
-            _dockPanes.AddRange(GetStartupPanes());
-            _layoutManager = new WindowsLayoutManager(mainContainer, _dockPanes);
-            _activeDocumentChanged = new TabbedDocumentManager.ActiveDocumentChangeHandler(tabbedDocumentContainer1_ActiveDocumentChanged);
-            _activeDocumentChanging = new TabbedDocumentManager.ActiveDocumentChangeHandler(tabbedDocumentContainer1_ActiveDocumentChanging);
-            tabbedDocumentContainer1.ActiveDocumentChanged += _activeDocumentChanged;
-            tabbedDocumentContainer1.ActiveDocumentChanging += _activeDocumentChanging;
+            
+            tabbedDocumentContainer1.ActiveDocumentChanged += new TabbedDocumentManager.ActiveDocumentChangeHandler(tabbedDocumentContainer1_ActiveDocumentChanged);
+            tabbedDocumentContainer1.ActiveDocumentChanging += new TabbedDocumentManager.ActiveDocumentChangeHandler(tabbedDocumentContainer1_ActiveDocumentChanging);
 			this.Load += new EventHandler(frmMain_Load);
             this.Activated += new EventHandler(frmMain_Activated);
             this.Deactivate += new EventHandler(frmMain_Deactivated);
         }
 
-        private List<DockContent> GetStartupPanes()
+        public List<DockContent> GetStartupPanes()
         {
-            return new List<DockContent>
+            return new List<DockContent> 
             {
                 projectPanel,
                 propertiesPanel,
@@ -62,11 +55,6 @@ namespace AGS.Editor
             };
         }
 
-        public WindowsLayoutManager GetLayoutManager()
-        {
-            return _layoutManager;
-        }
-
         private void frmMain_Activated(object sender, EventArgs e)
         {
             if (OnMainWindowActivated != null)
@@ -85,13 +73,8 @@ namespace AGS.Editor
 
 		private void frmMain_Load(object sender, EventArgs e)
 		{
-            if (!DesignMode)
-            {
-                LoadLayout();
-                Factory.GUIController.LoadWindowConfig();
-                Factory.GUIController.ColorThemes.Apply(LoadColorTheme);
-            }
-        }
+            LoadLayout();            			
+		}
 
         public void RefreshPropertyGridForDocument(ContentDocument document)
         {
@@ -114,13 +97,6 @@ namespace AGS.Editor
             }
         }
 
-        private void removeTabbedDocumentEventHandlers()
-        {
-            // we remove these events to prevent an exception when closing AGS with an object selected in the property grid
-            tabbedDocumentContainer1.ActiveDocumentChanged -= _activeDocumentChanged;
-            tabbedDocumentContainer1.ActiveDocumentChanging -= _activeDocumentChanging;
-        }
-
         private void tabbedDocumentContainer1_ActiveDocumentChanging(ContentDocument newActiveDocument)
         {
             if (tabbedDocumentContainer1.ActiveDocument != null)
@@ -128,11 +104,11 @@ namespace AGS.Editor
                 // Remember which pane and item were selected on the property grid,
                 // so that we can restore them later
                 tabbedDocumentContainer1.ActiveDocument.SelectedPropertyGridTab = 
-                    propertiesPanel.SelectedTab.TabName;
-                if (propertiesPanel.SelectedGridItem != null)
+                    propertiesPanel.propertiesGrid.SelectedTab.TabName;
+                if (propertiesPanel.propertiesGrid.SelectedGridItem != null)
                 {
                     tabbedDocumentContainer1.ActiveDocument.SelectedPropertyGridItem = 
-                        propertiesPanel.SelectedGridItem.Label;
+                        propertiesPanel.propertiesGrid.SelectedGridItem.Label;
                 }                
             }
         }
@@ -161,7 +137,7 @@ namespace AGS.Editor
 
         private GridItem FindPropertyGridItemForType(string fullTypeName)
         {
-            GridItem startFromHere = propertiesPanel.SelectedGridItem;
+            GridItem startFromHere = propertiesPanel.propertiesGrid.SelectedGridItem;
             if (startFromHere == null)
             {
                 return null;
@@ -188,16 +164,15 @@ namespace AGS.Editor
                 {
                     if ((itemToSelect.Parent != null) && (!itemToSelect.Parent.Expanded))
                     {
-                        propertiesPanel.ExpandAllGridItems();
+                        propertiesPanel.propertiesGrid.ExpandAllGridItems();
                     }
-                    propertiesPanel.SelectedGridItem = itemToSelect;
+                    propertiesPanel.propertiesGrid.SelectedGridItem = itemToSelect;
                 }
             }
         }
 
         private void tabbedDocumentContainer1_ActiveDocumentChanged(ContentDocument newActiveDocument)
         {
-            if (this == null) return;
             RefreshPropertyGridForDocument(newActiveDocument);
 
             if (newActiveDocument != null)
@@ -221,19 +196,6 @@ namespace AGS.Editor
 			}
 		}
 
-        public void AddDockPane(DockContent pane, DockData defaultDock)
-        {
-            if (!_dockPanes.Contains(pane))
-            {
-                _dockPanes.Add(pane);
-                pane.ShowHint = (DockState)defaultDock.DockState;
-                if (defaultDock.DockState == DockingState.Float)
-                    pane.Show(mainContainer, defaultDock.Location);
-                else
-                    pane.Show(mainContainer, (DockState)defaultDock.DockState);
-            }
-        }
-
         public void AddOrShowPane(ContentDocument pane)
         {
             if (!tabbedDocumentContainer1.ContainsDocument(pane))
@@ -251,21 +213,39 @@ namespace AGS.Editor
             }
         }
 
-        public IList<DockContent> DockPanes
-        {
-            get
-            {
-                return _dockPanes;
-            }
-        }
+		/*public void SetProjectTreeLocation(bool rightHandSide)
+		{
+			SplitterPanel leftHandPanel = this.mainContainer.Panel1;
+			SplitterPanel rightHandPanel = this.mainContainer.Panel2;
+			if ((rightHandSide) && (rightHandPanel.Controls.Contains(this.leftSplitter)))
+			{
+				// already on the right
+				return;
+			}
+			if ((!rightHandSide) && (leftHandPanel.Controls.Contains(this.leftSplitter)))
+			{
+				// already on the left
+				return;
+			}
+			leftHandPanel.Controls.Clear();
+			rightHandPanel.Controls.Clear();
+			SplitterPanel panelWithProjectTree = leftHandPanel;
+			SplitterPanel panelWithMainPane = rightHandPanel;
+			this.mainContainer.FixedPanel = System.Windows.Forms.FixedPanel.Panel1;
+			if (rightHandSide)
+			{
+				panelWithProjectTree = rightHandPanel;
+				panelWithMainPane = leftHandPanel;
+				this.mainContainer.FixedPanel = System.Windows.Forms.FixedPanel.Panel2;
+			}
 
-        public IList<ContentDocument> Panes
-        {
-            get
-            {
-                return tabbedDocumentContainer1.Documents;
-            }
-        }
+			panelWithMainPane.Controls.Add(this.tabbedDocumentContainer1);
+			panelWithMainPane.Controls.Add(this.pnlOutput);
+            panelWithMainPane.Controls.Add(this.pnlCallStack);
+            panelWithMainPane.Controls.Add(this.pnlFindResults);
+			panelWithProjectTree.Controls.Add(this.leftSplitter);
+			this.mainContainer.SplitterDistance = this.mainContainer.ClientSize.Width - this.mainContainer.SplitterDistance;
+		}*/
 
         public ContentDocument ActivePane
         {
@@ -284,7 +264,20 @@ namespace AGS.Editor
 
         public bool SelectTabInPropertyGrid(string tabName)
         {
-            return propertiesPanel.SelectTabInPropertyGrid(tabName);
+            int tabIndex = 0;
+            foreach (System.Windows.Forms.Design.PropertyTab propertyTab in propertiesPanel.propertiesGrid.PropertyTabs)
+            {
+                if (propertyTab.TabName == tabName)
+                {
+                    if (propertyTab != propertiesPanel.propertiesGrid.SelectedTab)
+                    {
+                    	Hacks.SetSelectedTabInPropertyGrid(propertiesPanel.propertiesGrid, tabIndex);
+                    }
+                    return true;
+                }
+                tabIndex++;
+            }
+            return false;
         }
 
         public Point GetPropertyGridScreenCoordinates()
@@ -297,12 +290,7 @@ namespace AGS.Editor
             propertiesPanel.Focus();
             // The property grid provides no RootGridItem property,
             // so we must find it manually
-            GridItem rootItem = propertiesPanel.SelectedGridItem;
-            if (rootItem == null)
-            {
-                return;
-            }
-
+            GridItem rootItem = propertiesPanel.propertiesGrid.SelectedGridItem;
             while (rootItem.GridItemType != GridItemType.Root)
             {
                 rootItem = rootItem.Parent;
@@ -368,45 +356,45 @@ namespace AGS.Editor
         }
 
         public void SetPropertyObject(object propertiesObject)
-        {
-            propertiesPanel.SelectedObject = propertiesObject;
+        {            
+            propertiesPanel.propertiesGrid.SelectedObject = propertiesObject;
             SelectObjectInPropertyList(propertiesObject);
         }
 
         public void SetPropertyObjects(object[] propertiesObjects)
         {
-            propertiesPanel.SelectedObjects = propertiesObjects;
+            propertiesPanel.propertiesGrid.SelectedObjects = propertiesObjects;
+
             propertiesPanel.propertyObjectCombo.SelectedIndex = -1;
         }
 
         private void SelectObjectInPropertyList(object propertiesObject)
         {
-            // Prevent occasional recursion (code logic around PropertyGrid is quite confusing)
-            if (_ignoreSelectObjectInList)
-                return;
-
-            try
+            if (_propertyObjectList != null)
             {
-                _ignoreSelectObjectInList = true;
-                if (_propertyObjectList != null)
+                foreach (string name in _propertyObjectList.Keys)
                 {
-                    foreach (string name in _propertyObjectList.Keys)
+                    if (_propertyObjectList[name] == propertiesObject)
                     {
-                        if (_propertyObjectList[name] == propertiesObject)
-                        {
-                            propertiesPanel.propertyObjectCombo.SelectedIndex =
-                                propertiesPanel.propertyObjectCombo.Items.IndexOf(name);
-                            break;
-                        }
+                        propertiesPanel.propertyObjectCombo.SelectedIndex =
+                            propertiesPanel.propertyObjectCombo.Items.IndexOf(name);
                     }
                 }
             }
-            finally
-            {
-                _ignoreSelectObjectInList = false;
-            }
         }
 
+		/*public void SetSplitterPositions(int mainSplitterX, int propertiesSplitterY)
+		{
+			_splitterXtoSet = mainSplitterX;
+			_splitterYtoSet = propertiesSplitterY;
+		}
+
+		public void GetSplitterPositions(out int mainSplitterX, out int propertiesSplitterY)
+		{
+            mainSplitterX = 0;// this.mainContainer.SplitterDistance;
+            propertiesSplitterY = 0;// this.leftSplitter.SplitterDistance;
+		}*/
+
         private void frmMain_FormClosing(object sender, FormClosingEventArgs e)
         {
             if (OnEditorShutdown != null)
@@ -415,10 +403,6 @@ namespace AGS.Editor
             }
             if (!e.Cancel)
             {
-                // Explicitly remove all document panes in order to trigger their OnPanelClosing,
-                // where they possibly save their states to a WindowConfig.
-                tabbedDocumentContainer1.RemoveAllDocuments(false);
-                Factory.GUIController.SaveWindowConfig();
                 _layoutManager.SaveLayout();
             }
         }
@@ -436,50 +420,35 @@ namespace AGS.Editor
         private void frmMain_Shown(object sender, EventArgs e)
         {
             this.tabbedDocumentContainer1.Init();
+            
+            if (AGS.Types.Version.IS_BETA_VERSION)
+			{
+				Factory.GUIController.ShowMessage("This is a BETA version of AGS. BE VERY CAREFUL and MAKE SURE YOU BACKUP YOUR GAME before loading it in this editor.", MessageBoxIcon.Warning);
+			}
 
-            ShowTabIcons = Factory.AGSEditor.Settings.ShowIconInTab;
-            Factory.GUIController.ShowWelcomeScreen();
+			if (!Factory.GUIController.ShowWelcomeScreen())
+			{
+				Factory.GUIController.ShowCuppit("To get started, check out the tree in the top-right hand corner. That's the main way you'll be moving between different parts of the editor.", "Initial editor welcome");
+			}
         }
 
         private void LoadLayout()
         {
-            var res = _layoutManager.LoadLayout();
-            if (res == WindowsLayoutManager.LayoutResult.LayoutException)
-                Factory.GUIController.ShowMessage("Failed to load panel layout: the layout file may be corrupt or contains invalid data. The layout will be reset.", MessageBoxIcon.Error);
-            if (res != WindowsLayoutManager.LayoutResult.OK)
+            _layoutManager = new WindowsLayoutManager(mainContainer,
+                GetStartupPanes());
+            if (!_layoutManager.LoadLayout())
             {
-                ResetLayoutToDefaults();
-            }
+                SetDefaultLayout();
+            }            
         }
 
-        /// <summary>
-        /// Resets Editor layout.
-        /// </summary>
-        public void ResetLayoutToDefaults()
-        {
-            // Ask layout manager to restore using its own defaults
-            if (_layoutManager.ResetToDefaults() != WindowsLayoutManager.LayoutResult.OK)
-            {
-                SetDefaultLayout(); // last chance fallback
-            }
-        }
-
-        /// <summary>
-        /// Sets hard-coded layout; this is a last resort action.
-        /// </summary>
         private void SetDefaultLayout()
         {
-            _layoutManager.DetachAll();
-            mainContainer.DockLeftPortion = 0.25f;
-            mainContainer.DockRightPortion = 0.25f;
-            mainContainer.DockTopPortion = 0.25f;
-            mainContainer.DockBottomPortion = 0.25f;
-            pnlCallStack.Show(mainContainer, DockState.DockBottom);
-            pnlFindResults.Show(pnlCallStack.Pane, pnlCallStack);
-            pnlOutput.Show(pnlCallStack.Pane, pnlFindResults);
-            projectPanel.Show(mainContainer, DockState.DockRight);
-            propertiesPanel.Show(projectPanel.Pane, DockAlignment.Bottom, 0.5f);
-            _layoutManager.RestoreDetached();
+            this.pnlCallStack.Show(mainContainer, DockState.DockBottom);
+            this.pnlFindResults.Show(pnlCallStack.Pane, pnlCallStack);
+            this.pnlOutput.Show(pnlCallStack.Pane, pnlFindResults);            
+            this.projectPanel.Show();
+            this.propertiesPanel.Show();                        
         }
 
         private void propertyObjectCombo_SelectedIndexChanged(object sender, EventArgs e)
@@ -528,63 +497,5 @@ namespace AGS.Editor
             //SetPropertyObject(null);
         }
 
-        public bool ShowTabIcons
-        {
-            get { return mainContainer.ShowDocumentIcon; }
-            set { mainContainer.ShowDocumentIcon = value; }
-        }
-
-        private void LoadColorTheme(ColorTheme t)
-        {
-            t.SetColor("background", c => BackColor = c);
-            t.SetColor(new string[] { "main-container/dock-background", "background" }, c => mainContainer.DockBackColor = c);
-            t.SetColor("main-container/background", c => mainContainer.BackColor = c);
-            t.SetColor("main-container/foreground", c => mainContainer.ForeColor = c);
-            // VS2005 theme only (skin)
-            t.SetColor("main-container/skin/auto-hide/tab-gradient/start", c => mainContainer.Skin.AutoHideStripSkin.TabGradient.StartColor = c);
-            t.SetColor("main-container/skin/auto-hide/tab-gradient/end", c => mainContainer.Skin.AutoHideStripSkin.TabGradient.EndColor = c);
-            t.SetColor("main-container/skin/auto-hide/tab-gradient/text", c => mainContainer.Skin.AutoHideStripSkin.TabGradient.TextColor = c);
-            t.SetColor("main-container/skin/auto-hide/dock-strip-gradient/start", c => mainContainer.Skin.AutoHideStripSkin.DockStripGradient.StartColor = c);
-            t.SetColor("main-container/skin/auto-hide/dock-strip-gradient/end", c => mainContainer.Skin.AutoHideStripSkin.DockStripGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/dock-strip-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.DockStripGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/dock-strip-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.DockStripGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/active-tab-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.ActiveTabGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/active-tab-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.ActiveTabGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/active-tab-gradient/text", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.ActiveTabGradient.TextColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/inactive-tab-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.InactiveTabGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/inactive-tab-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.InactiveTabGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/document-gradient/inactive-tab-gradient/text", c => mainContainer.Skin.DockPaneStripSkin.DocumentGradient.InactiveTabGradient.TextColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/active-caption-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.ActiveCaptionGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/active-caption-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.ActiveCaptionGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/active-caption-gradient/text", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.ActiveCaptionGradient.TextColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/inactive-caption-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.InactiveCaptionGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/inactive-caption-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.InactiveCaptionGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/inactive-caption-gradient/text", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.InactiveCaptionGradient.TextColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/active-tab-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.ActiveTabGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/active-tab-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.ActiveTabGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/active-tab-gradient/text", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.ActiveTabGradient.TextColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/inactive-tab-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.InactiveTabGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/inactive-tab-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.InactiveTabGradient.EndColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/inactive-tab-gradient/text", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.InactiveTabGradient.TextColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/dock-strip-gradient/start", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.DockStripGradient.StartColor = c);
-            t.SetColor("main-container/skin/dock-pane/tool-window/dock-strip-gradient/end", c => mainContainer.Skin.DockPaneStripSkin.ToolWindowGradient.DockStripGradient.EndColor = c);
-
-            if ( t.Has("main-menu") )
-            {
-                t.SetColor("main-menu/background", c => mainMenu.BackColor = c);
-                mainMenu.Renderer = t.GetMainMenuRenderer("main-menu");
-                mainMenu.Renderer.RenderItemText += (s, a) => a.ToolStrip.ForeColor = t.GetColor("main-menu/foreground");
-                mainMenu.Renderer.RenderItemCheck += (s, a) => a.Graphics.DrawImage(t.GetImage("main-menu/check/foreground", a.Image), a.ImageRectangle);
-            }
-
-            if (t.Has("tool-bar"))
-            {
-                t.SetColor("tool-bar/background", c => mainMenu.BackColor = c);
-                toolStrip.Renderer = t.GetToolStripRenderer("tool-bar");
-            }
-            
-            t.SetColor("status-strip/background", c => statusStrip.BackColor = c);
-            t.SetColor("status-strip/foreground", c => statusStrip.ForeColor = c);
-        }
     }
 }
\ No newline at end of file
