@@ -31,14 +31,9 @@ namespace AGS.Editor
             GameChanged();
         }
 
-        protected override void OnPropertyChanged(string propertyName, object oldValue)
-        {
-            palettePage.Invalidate(true);
-        }
-
         protected override string OnGetHelpKeyword()
         {
-            return "Colours Editor";
+            return "Palette setup";
         }
         
         public void GameChanged()
@@ -54,7 +49,7 @@ namespace AGS.Editor
             }
             else
             {
-                lblPaletteIntro.Text = "This palette information will only be used for drawing any 8-bit graphics that you may have imported.";
+                lblPaletteIntro.Text = "Since your game is hi-color, this palette information will only be used for drawing any 8-bit graphics that you may have imported.";
                 if (!tabControl.TabPages.Contains(_colourFinder))
                 {
                     tabControl.TabPages.Add(_colourFinder);
@@ -72,19 +67,19 @@ namespace AGS.Editor
 
         private void trackBarRed_Scroll(object sender, EventArgs e)
         {
-            ColourSlidersUpdated();
+            lblRedVal.Text = trackBarRed.Value.ToString();
             UpdateNumberFromScrollBars();
         }
 
         private void trackBarGreen_Scroll(object sender, EventArgs e)
         {
-            ColourSlidersUpdated();
+            lblGreenVal.Text = trackBarGreen.Value.ToString();
             UpdateNumberFromScrollBars();
         }
 
         private void trackBarBlue_Scroll(object sender, EventArgs e)
         {
-            ColourSlidersUpdated();
+            lblBlueVal.Text = trackBarBlue.Value.ToString();
             UpdateNumberFromScrollBars();
         }
 
@@ -99,37 +94,27 @@ namespace AGS.Editor
                     newVal = 0;
                 }
 
-                Color newColor = AGSEditor.Instance.ColorMapper.AgsColourNumberToColorDirect(newVal);
-                trackBarRed.Value = newColor.R;
-                trackBarGreen.Value = newColor.G;
-                trackBarBlue.Value = newColor.B;
+                trackBarRed.Value = (newVal >> 11) * 8;
+                trackBarGreen.Value = ((newVal >> 5) & 0x003f) * 4;
+                trackBarBlue.Value = (newVal & 0x001f) * 8;
 				lblFixedColorsWarning.Visible = ((newVal >= 1) && (newVal <= 31));
 				ColourSlidersUpdated();
             }
         }
 
-        private void ColourSlidersUpdated()
-        {
-            lblRedVal.Text = trackBarRed.Value.ToString();
-            lblGreenVal.Text = trackBarGreen.Value.ToString();
-            lblBlueVal.Text = trackBarBlue.Value.ToString();
-            // Ensure that we also display an honest clamped RGB values;
-            // we'd rather have users see an exact RGB which will be used in game,
-            // than to display a desired RGB that is going to be "secretly" clamped at runtime.
-            Color rgb = Color.FromArgb(trackBarRed.Value, trackBarGreen.Value, trackBarBlue.Value);
-            rgb = AGSEditor.Instance.ColorMapper.AgsColourNumberToColorDirect(
-                AGSEditor.Instance.ColorMapper.ColorToAgsColourNumberDirect(rgb));
-            lblRedFinal.Text = string.Format($"({rgb.R})");
-            lblGreenFinal.Text = string.Format($"({rgb.G})");
-            lblBlueFinal.Text = string.Format($"({rgb.B})");
-            blockOfColour.Invalidate();
-        }
+		private void ColourSlidersUpdated()
+		{
+			lblRedVal.Text = trackBarRed.Value.ToString();
+			lblGreenVal.Text = trackBarGreen.Value.ToString();
+			lblBlueVal.Text = trackBarBlue.Value.ToString();
+			blockOfColour.Invalidate();
+		}
 
         private void UpdateNumberFromScrollBars()
         {
             _noUpdates = true;
-            var newColor = Color.FromArgb(trackBarRed.Value, trackBarGreen.Value, trackBarBlue.Value);
-            int newValue = AGSEditor.Instance.ColorMapper.ColorToAgsColourNumberDirect(newColor);
+			int greenValue = trackBarGreen.Value / 4;
+            int newValue = (trackBarBlue.Value / 8) + (greenValue << 5) + ((trackBarRed.Value / 8) << 11);
             txtColourNumber.Text = newValue.ToString();
             _noUpdates = false;
             lblFixedColorsWarning.Visible = ((newValue >= 1) && (newValue <= 31));
@@ -270,7 +255,7 @@ namespace AGS.Editor
                     }
                     catch (Exception ex)
                     {
-                        Factory.GUIController.ShowError("There was an error exporting the palette.", ex, MessageBoxIcon.Warning);
+                        Factory.GUIController.ShowMessage("There was an error exporting the palette. The error message was '" + ex.Message + "'. Please retry.", MessageBoxIcon.Warning);
                     }
                 }
             }
@@ -287,7 +272,6 @@ namespace AGS.Editor
                             Factory.AGSEditor.CurrentGame.Palette[i] = newPalette[i];
                         }
                         palettePanel.Invalidate();
-                        Factory.NativeProxy.PaletteColoursChanged(Factory.AGSEditor.CurrentGame);
                     }
                 }
             }
@@ -320,7 +304,7 @@ namespace AGS.Editor
                 }
                 catch (Exception ex)
                 {
-                    Factory.GUIController.ShowError("There was an error importing the palette.", ex, MessageBoxIcon.Warning);
+                    Factory.GUIController.ShowMessage("There was an error importing the palette. The error message was '" + ex.Message + "'. Please retry.", MessageBoxIcon.Warning);
                 }
             }
             return newPalette;
@@ -364,9 +348,6 @@ namespace AGS.Editor
 
         private void GUIController_OnPropertyObjectChanged(object newPropertyObject)
         {
-            if (GUIController.Instance.ActivePane != ContentDocument)
-                return; // not this pane
-
             if (newPropertyObject is PaletteEntry)
             {
                 _selectedIndexes.Clear();
@@ -396,45 +377,5 @@ namespace AGS.Editor
 			}
 			dialog.Dispose();
 		}
-
-        private void LoadColorTheme(ColorTheme t)
-        {
-            t.ControlHelper(this, "palette");
-            t.ControlHelper(colourFinderPage, "palette/color-finder");
-            t.ControlHelper(palettePage, "palette/palette-page");
-            t.GroupBoxHelper(groupBox1, "palette/color-finder");
-            t.TextBoxHelper(txtColourNumber, "palette/color-finder/color-number-box");
-            t.ButtonHelper(btnColorDialog, "palette/color-finder/btn-color-dialog");
-            t.GroupBoxHelper(groupBox2, "palette/palette-page");
-
-            if (t.Has("palette/draw-mode"))
-                tabControl.DrawMode = (TabDrawMode)t.GetInt("palette/draw-mode");
-            if (t.Has("palette/draw-item"))
-            {
-                tabControl.DrawItem += (s, a) =>
-                {
-                    if (a.Index == tabControl.SelectedIndex)
-                    {
-                        a.Graphics.FillRectangle(new SolidBrush(t.GetColor("palette/draw-item/background/selected")), a.Bounds);
-                    }
-                    else
-                    {
-                        a.Graphics.Clear(t.GetColor("palette/draw-item/background/not-selected"));
-                    }
-
-                    TabPage tab = tabControl.TabPages[a.Index];
-                    a.Graphics.DrawString(tab.Text, tab.Font, new SolidBrush(t.GetColor("palette/draw-item/foreground")), a.Bounds.X, a.Bounds.Y + 5);
-                };
-            }
-
-        }
-
-        private void PaletteEditor_Load(object sender, EventArgs e)
-        {
-            if (!DesignMode)
-            {
-                Factory.GUIController.ColorThemes.Apply(LoadColorTheme);
-            }
-        }
     }
 }
