@@ -15,8 +15,6 @@ namespace AGS.Editor
         private bool _hadFirstEntryPoint = false;
         private Dictionary<int, object> _existingEntryPoints = new Dictionary<int, object>();
         private Game _game;
-        private string _sayFnName;
-        private string _narrateFnName;
 
         private static readonly string _DefaultDialogScriptsScript = null;
 
@@ -63,12 +61,6 @@ namespace AGS.Editor
             _currentlyInsideCodeArea = false;
             _hadFirstEntryPoint = false;
             _game = game;
-            _sayFnName = game.Settings.DialogScriptSayFunction;
-            if (string.IsNullOrWhiteSpace(_sayFnName))
-                _sayFnName = "Say";
-            _narrateFnName = game.Settings.DialogScriptNarrateFunction;
-            if (string.IsNullOrWhiteSpace(_narrateFnName))
-                _narrateFnName = "Display";
             _currentDialog = dialog;
             _existingEntryPoints.Clear();
             _currentLineNumber = 0;
@@ -131,12 +123,14 @@ namespace AGS.Editor
             int thisAtIndex = -1;
             while ((thisAtIndex = thisLine.IndexOf("this", thisAtIndex + 1)) > 0)
             {
-                if (thisLine[thisAtIndex - 1].IsScriptWordChar())
+                if (Char.IsLetterOrDigit(thisLine[thisAtIndex - 1]) ||
+                    (thisLine[thisAtIndex - 1] == '_'))
                 {
                     continue;
                 }
                 if ((thisAtIndex < thisLine.Length - 4) &&
-                    (thisLine[thisAtIndex + 4].IsScriptWordChar()))
+                    ((Char.IsLetterOrDigit(thisLine[thisAtIndex + 4]) ||
+                     (thisLine[thisAtIndex + 4] == '_'))))
                 {
                     continue;
                 }
@@ -187,7 +181,7 @@ namespace AGS.Editor
             {
                 // the old dialog script compiler allowed semicolons,
                 // so just strip them out
-                dlgScriptCommand = dlgScriptCommand.ToLowerInvariant().Replace(";", "");
+                dlgScriptCommand = dlgScriptCommand.ToLower().Replace(";", "");
                 
                 if (dlgScriptCommand == "return")
                 {
@@ -331,7 +325,7 @@ namespace AGS.Editor
             }
             string charName = result.Groups[1].Captures[0].Value;
             string viewNumber = result.Groups[2].Captures[0].Value;
-            Character character = FindCharacterByScriptName(charName.ToLowerInvariant());
+            Character character = FindCharacterByScriptName(charName.ToLower());
             return string.Format("{0}.SpeechView = {1};", character.ScriptName, viewNumber);
         }
 
@@ -358,46 +352,40 @@ namespace AGS.Editor
             return string.Format("dialog[{0}].SetOptionState({1}, {2});", _currentDialog.ID, optionNumber, optionStateEnum);
         }
 
-        private string MakeCharacterSpeechLine(string charName, string textToSay)
+        private string ProcessCharacterSpeechLine(string dlgScriptCommand)
         {
-            // Note that textToSay does not have to be a literal string, could be a function call for example
             string scriptToReturn = string.Empty;
+            int colonAtIndex = dlgScriptCommand.IndexOf(':');
+            string charName = dlgScriptCommand.Substring(0, colonAtIndex).Trim().ToLower();
+            string textToSay = dlgScriptCommand.Substring(colonAtIndex + 1).Trim();
+            if (textToSay == string.Empty)
+            {
+                textToSay = "...";
+            }
+            textToSay = textToSay.Replace("\"", "\\\"");
             if (charName == "player")
             {
-                scriptToReturn = string.Format("player.{0}({1});", _sayFnName, textToSay);
+                scriptToReturn = string.Format("player.Say(\"{0}\");", textToSay);
             }
             else if (charName == "narrator")
             {
-                scriptToReturn = string.Format("{0}({1});", _narrateFnName, textToSay);
+                scriptToReturn = string.Format("Display(\"{0}\");", textToSay);
             }
             else
             {
                 Character character = FindCharacterByScriptName(charName);
-                scriptToReturn = string.Format("{0}.{1}({2});", character.ScriptName, _sayFnName, textToSay);
+                scriptToReturn = string.Format("{0}.Say(\"{1}\");", character.ScriptName, textToSay);
             }
             return scriptToReturn;
         }
 
-        private string ProcessCharacterSpeechLine(string dlgScriptCommand)
-        {
-            int colonAtIndex = dlgScriptCommand.IndexOf(':');
-            string charName = dlgScriptCommand.Substring(0, colonAtIndex).Trim().ToLowerInvariant();
-            string textToSay = dlgScriptCommand.Substring(colonAtIndex + 1).Trim();
-            if (textToSay == string.Empty)
-                textToSay = "...";
-            else
-                textToSay = textToSay.Replace("\"", "\\\"");
-            textToSay = string.Format("\"{0}\"", textToSay);
-            return MakeCharacterSpeechLine(charName, textToSay);
-        }
-
         private Character FindCharacterByScriptName(string scriptName)
         {
             string scriptNameWithCPrefix = "c" + scriptName;
 
             foreach (Character character in _game.RootCharacterFolder.AllItemsFlat)
             {
-                string thisCharName = character.ScriptName.ToLowerInvariant();
+                string thisCharName = character.ScriptName.ToLower();
                 if ((thisCharName == scriptName) ||
                     (thisCharName == scriptNameWithCPrefix))
                 {
@@ -448,20 +436,6 @@ namespace AGS.Editor
             scriptToWrite += string.Format("if (entryPoint == {0}) {1}", entryPointID, "{");
             _hadFirstEntryPoint = true;
             _currentlyInsideCodeArea = true;
-
-            /* --- disabled until Dialog.DisplayOptions(eSayAlways/eSayNever) question is resolved ---
-             *
-            // Add player.Say if the Say checkbox is set for this option
-            if (entryPointID > 0)
-            {
-                int optionID = entryPointID - 1;
-                string dlgName = _currentDialog.Name;
-                if (_currentDialog.Options[optionID].Say)
-                    // Use GetOptionText here in case future script API supports changing option text at runtime
-                    scriptToWrite += MakeCharacterSpeechLine("player", string.Format("{0}.GetOptionText({1})", dlgName, optionID + 1));
-            }
-            */
-
             return scriptToWrite;
         }
 
