@@ -9,12 +9,12 @@ namespace AGS.Types
 	public class RoomTemplate : BaseTemplate
 	{
 		public RoomTemplate(string fileName, Icon icon)
-			: base(fileName, null, icon)
+			: base(fileName, icon)
 		{
 		}
 
 		public RoomTemplate(string fileName, Icon icon, string friendlyName)
-			: base(fileName, null, icon)
+			: base(fileName, icon)
 		{
 			_friendlyName = friendlyName;
 		}
