@@ -6,8 +6,8 @@ namespace AGS.Types
 {
     public abstract class CompileMessage : ApplicationException
     {
-        private string _scriptName = string.Empty;
-        private int _lineNumber = 0;
+        private string _scriptName;
+        private int _lineNumber;
 
         public CompileMessage(string message, string scriptName, int lineNumber)
             : base(message)
@@ -19,11 +19,15 @@ namespace AGS.Types
         public CompileMessage(string message)
             : base(message)
         {
+            _scriptName = string.Empty;
+            _lineNumber = 0;
         }
 
         public CompileMessage(string message, Exception innerException)
             : base(message, innerException)
         {
+            _scriptName = string.Empty;
+            _lineNumber = 0;
         }
 
         public CompileMessage(CompileMessage other) : base(other.Message)
@@ -42,26 +46,5 @@ namespace AGS.Types
             get { return _lineNumber; }
         }
 
-        public string AsString
-        {
-            get
-            {
-                string fullMessage;
-                if(_lineNumber == 0 && string.IsNullOrEmpty(_scriptName))
-                {
-                    fullMessage = Message;
-                }
-                else
-                {
-                    fullMessage = Message + " at line " + _lineNumber.ToString() + " in " + _scriptName + ".";
-                }
-
-                for (Exception innerException = InnerException; innerException != null; innerException = innerException.InnerException)
-                {
-                    fullMessage += $"{Environment.NewLine}{Environment.NewLine}{innerException.Message}";
-                }
-                return fullMessage;
-            }
-        }
     }
 }
