@@ -1,9 +1,8 @@
-﻿using System;
-using System.Reflection;
+﻿using System.Reflection;
 using System.Runtime.CompilerServices;
 using System.Runtime.InteropServices;
 
-// General Information about an assembly is controlled through the following
+// General Information about an assembly is controlled through the following 
 // set of attributes. Change these attribute values to modify the information
 // associated with an assembly.
 [assembly: AssemblyTitle("AGSTypes")]
@@ -20,14 +19,12 @@ using System.Runtime.InteropServices;
 
 namespace AGS.Types
 {
-    public class Version
-    {
-        public static readonly bool IS_BETA_VERSION = false;
-        public const string AGS_EDITOR_DATE = "October 2025";
-        public const string AGS_EDITOR_FRIENDLY_VERSION = "3.6.2";
-        public const string AGS_EDITOR_VERSION = "3.6.2.14";
-        public const string AGS_EDITOR_COPYRIGHT = "Copyright © 2006-2011 Chris Jones and 2011-2025 others.";
-        public static readonly string AGS_EDITOR_TARGETNAME =
-            IntPtr.Size > 4 ? "64-bit" : "32-bit";
-    }
-}
+	public class Version
+	{
+		public static readonly bool IS_BETA_VERSION = true;
+		public const string AGS_EDITOR_DATE = "September 2013";
+		public const string AGS_EDITOR_FRIENDLY_VERSION = "3.3.0";
+        public const string AGS_EDITOR_VERSION = "3.3.0.1147";
+        public const string AGS_EDITOR_COPYRIGHT = "Copyright © 2006-2011 Chris Jones and 2011-2013 others.";
+	}
+}
\ No newline at end of file
