@@ -7,19 +7,19 @@ using System.Reflection;
 
 namespace AGS.Types
 {
-    public class AudioClipTypeTypeConverter : BaseListSelectTypeConverter<int, string>
+    public class AudioClipTypeTypeConverter : BaseListSelectTypeConverter
     {
         private static Dictionary<int, string> _possibleValues = new Dictionary<int, string>();
         private static IList<AudioClipType> _AudioClipTypes = null;
 
-        protected override Dictionary<int, string> GetValueList(ITypeDescriptorContext context)
+        protected override Dictionary<int, string> GetValueList()
         {
             return _possibleValues;
         }
 
         public static void SetAudioClipTypeList(IList<AudioClipType> audioClipTypes)
         {
-            // Keep a reference to the list so it can be updated whenever we need to
+            // Keep a refernce to the list so it can be updated whenever we need to
             _AudioClipTypes = audioClipTypes;
             RefreshAudioClipTypeList();
         }
