@@ -6,31 +6,9 @@ using System.Xml;
 
 namespace AGS.Types
 {
-    [DefaultProperty("TextColor")]
     public class TextWindowGUI : GUI
     {
 		private int _textColor;
-		private int _padding = 3;
-
-        /// <summary>
-        /// Width of the GUI, as displayed in the Editor.
-        /// </summary>
-        [Browsable(false)]
-        [AGSNoSerialize]
-        public override int EditorWidth
-        {
-            get { return 200; }
-        }
-
-        /// <summary>
-        /// Height of the GUI, as displayed in the Editor.
-        /// </summary>
-        [Browsable(false)]
-        [AGSNoSerialize]
-        public override int EditorHeight
-        {
-            get { return 100; }
-        }
 
 		[Description("Colour of the text when drawn on this text window")]
 		[Category("Appearance")]
@@ -40,14 +18,6 @@ namespace AGS.Types
 			set { _textColor = value; }
 		}
 
-		[Description("The amount of padding, in pixels, surrounding the text in this text window")]
-		[Category("Appearance")]
-		public int Padding
-		{
-			get { return _padding; }
-			set { _padding = value; }
-		}
-
 		// For backwards compatibility, before 3.0.0.19 stored
 		// it as "BorderColor"
 		[Browsable(false)]
@@ -68,8 +38,6 @@ namespace AGS.Types
             _controls.Add(new GUITextWindowEdge(90, 40, 5));
             _controls.Add(new GUITextWindowEdge(40, 0, 6));
             _controls.Add(new GUITextWindowEdge(40, 90, 7));
-            foreach (var control in _controls)
-                control.Parent = this;
         }
         
         public TextWindowGUI(XmlNode rootGuiNode) : base(rootGuiNode)
