@@ -2,86 +2,62 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
-#include "ac/datetime.h"
-#include "ac/dynobj/dynobj_manager.h"
-#include "debug/debug_log.h"
-#include "platform/base/agsplatformdriver.h"
 
+#include <time.h>
+#include "ac/datetime.h"
+#include "platform/base/agsplatformdriver.h"
+#include "script/runtimescriptvalue.h"
+
+ScriptDateTime* DateTime_Now_Core() {
+    ScriptDateTime *sdt = new ScriptDateTime();
+    sdt->rawUnixTime = time(NULL);
+
+    platform->GetSystemTime(sdt);
+
+    return sdt;
+}
 
 ScriptDateTime* DateTime_Now() {
-    ScriptDateTime *sdt = new ScriptDateTime(ScriptDateTime::SystemClock::now());
-    ccRegisterManagedObject(sdt, sdt);
-    return sdt;
-}
-
-ScriptDateTime* DateTime_CreateFromDate(int year, int month, int day, int hour, int minute, int second) {
-    // NOTE: implementation cannot handle years before 1970,
-    // and since DateTime.RawTime is int32, years from 2038 and above cause overflow.
-    ScriptDateTime *sdt;
-    if (year < 1970 || year >= 2038 || month < 1 || month > 12 || day < 1 || day > 31 || hour < 0 || hour > 23 || minute < 0 || minute > 59 || second < 0 || second > 59)
-    {
-        debug_script_warn("DateTime.CreateFromDate: requested date or time is not in a supported range: %dy,%dm,%dd %dh:%dm:%ds",
-            year, month, day, hour, minute, second);
-        sdt = new ScriptDateTime();
-    }
-    else
-    {
-        sdt = ScriptDateTime::FromFullDate(year, month, day, hour, minute, second);
-    }
-    ccRegisterManagedObject(sdt, sdt);
-    return sdt;
-}
-
-ScriptDateTime* DateTime_CreateFromRawTime(int raw_time) {
-    ScriptDateTime *sdt;
-    if (raw_time < 0)
-    {
-        debug_script_warn("DateTime.CreateFromRawTime: raw time is not in a supported range: %d", raw_time);
-        sdt = new ScriptDateTime();
-    }
-    else
-    {
-        sdt = ScriptDateTime::FromRawTime(raw_time);
-    }
+    ScriptDateTime *sdt = DateTime_Now_Core();
     ccRegisterManagedObject(sdt, sdt);
     return sdt;
 }
 
 int DateTime_GetYear(ScriptDateTime *sdt) {
-    return sdt->Year();
+    return sdt->year;
 }
 
 int DateTime_GetMonth(ScriptDateTime *sdt) {
-    return sdt->Month();
+    return sdt->month;
 }
 
 int DateTime_GetDayOfMonth(ScriptDateTime *sdt) {
-    return sdt->Day();
+    return sdt->day;
 }
 
 int DateTime_GetHour(ScriptDateTime *sdt) {
-    return sdt->Hour();
+    return sdt->hour;
 }
 
 int DateTime_GetMinute(ScriptDateTime *sdt) {
-    return sdt->Minute();
+    return sdt->minute;
 }
 
 int DateTime_GetSecond(ScriptDateTime *sdt) {
-    return sdt->Second();
+    return sdt->second;
 }
 
 int DateTime_GetRawTime(ScriptDateTime *sdt) {
-    return sdt->RawTime();
+    return sdt->rawUnixTime;
 }
 
 //=============================================================================
@@ -100,16 +76,6 @@ RuntimeScriptValue Sc_DateTime_Now(const RuntimeScriptValue *params, int32_t par
     API_SCALL_OBJAUTO(ScriptDateTime, DateTime_Now);
 }
 
-RuntimeScriptValue Sc_DateTime_CreateFromRawTime(const RuntimeScriptValue *params, int32_t param_count)
-{
-    API_SCALL_OBJAUTO_PINT(ScriptDateTime, DateTime_CreateFromRawTime);
-}
-
-RuntimeScriptValue Sc_DateTime_CreateFromDate(const RuntimeScriptValue *params, int32_t param_count)
-{
-    API_SCALL_OBJAUTO_PINT6(ScriptDateTime, DateTime_CreateFromDate);
-}
-
 // int (ScriptDateTime *sdt)
 RuntimeScriptValue Sc_DateTime_GetYear(void *self, const RuntimeScriptValue *params, int32_t param_count)
 {
@@ -154,19 +120,23 @@ RuntimeScriptValue Sc_DateTime_GetRawTime(void *self, const RuntimeScriptValue *
 
 void RegisterDateTimeAPI()
 {
-    ScFnRegister datetime_api[] = {
-        { "DateTime::get_Now",        API_FN_PAIR(DateTime_Now) },
-        { "DateTime::CreateFromDate", API_FN_PAIR(DateTime_CreateFromDate) },
-        { "DateTime::CreateFromRawTime", API_FN_PAIR(DateTime_CreateFromRawTime) },
+    ccAddExternalStaticFunction("DateTime::get_Now",        Sc_DateTime_Now);
+    ccAddExternalObjectFunction("DateTime::get_DayOfMonth", Sc_DateTime_GetDayOfMonth);
+    ccAddExternalObjectFunction("DateTime::get_Hour",       Sc_DateTime_GetHour);
+    ccAddExternalObjectFunction("DateTime::get_Minute",     Sc_DateTime_GetMinute);
+    ccAddExternalObjectFunction("DateTime::get_Month",      Sc_DateTime_GetMonth);
+    ccAddExternalObjectFunction("DateTime::get_RawTime",    Sc_DateTime_GetRawTime);
+    ccAddExternalObjectFunction("DateTime::get_Second",     Sc_DateTime_GetSecond);
+    ccAddExternalObjectFunction("DateTime::get_Year",       Sc_DateTime_GetYear);
 
-        { "DateTime::get_DayOfMonth", API_FN_PAIR(DateTime_GetDayOfMonth) },
-        { "DateTime::get_Hour",       API_FN_PAIR(DateTime_GetHour) },
-        { "DateTime::get_Minute",     API_FN_PAIR(DateTime_GetMinute) },
-        { "DateTime::get_Month",      API_FN_PAIR(DateTime_GetMonth) },
-        { "DateTime::get_RawTime",    API_FN_PAIR(DateTime_GetRawTime) },
-        { "DateTime::get_Second",     API_FN_PAIR(DateTime_GetSecond) },
-        { "DateTime::get_Year",       API_FN_PAIR(DateTime_GetYear) },
-    };
+    /* ----------------------- Registering unsafe exports for plugins -----------------------*/
 
-    ccAddExternalFunctions(datetime_api);
+    ccAddExternalFunctionForPlugin("DateTime::get_Now",        (void*)DateTime_Now);
+    ccAddExternalFunctionForPlugin("DateTime::get_DayOfMonth", (void*)DateTime_GetDayOfMonth);
+    ccAddExternalFunctionForPlugin("DateTime::get_Hour",       (void*)DateTime_GetHour);
+    ccAddExternalFunctionForPlugin("DateTime::get_Minute",     (void*)DateTime_GetMinute);
+    ccAddExternalFunctionForPlugin("DateTime::get_Month",      (void*)DateTime_GetMonth);
+    ccAddExternalFunctionForPlugin("DateTime::get_RawTime",    (void*)DateTime_GetRawTime);
+    ccAddExternalFunctionForPlugin("DateTime::get_Second",     (void*)DateTime_GetSecond);
+    ccAddExternalFunctionForPlugin("DateTime::get_Year",       (void*)DateTime_GetYear);
 }
