@@ -2,40 +2,39 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
-#include "ac/dynobj/cc_dialog.h"
-#include "ac/dynobj/dynobj_manager.h"
-#include "ac/dialog.h"
-#include "ac/dialogtopic.h"
-#include "ac/gamestructdefines.h"
-#include "util/stream.h"
 
-using namespace AGS::Common;
+#include "ac/dynobj/cc_dialog.h"
+#include "ac/dialogtopic.h"
+#include "ac/dynobj/scriptdialog.h"
+#include "ac/gamestructdefines.h"
+
+extern ScriptDialog scrDialog[MAX_DIALOG];
 
 // return the type name of the object
 const char *CCDialog::GetType() {
     return "Dialog";
 }
 
-size_t CCDialog::CalcSerializeSize(const void* /*address*/)
-{
-    return sizeof(int32_t);
+// serialize the object into BUFFER (which is BUFSIZE bytes)
+// return number of bytes used
+int CCDialog::Serialize(const char *address, char *buffer, int bufsize) {
+    ScriptDialog *shh = (ScriptDialog*)address;
+    StartSerialize(buffer);
+    SerializeInt(shh->id);
+    return EndSerialize();
 }
 
-void CCDialog::Serialize(const void *address, Stream *out) {
-    const ScriptDialog *shh = static_cast<const ScriptDialog*>(address);
-    out->WriteInt32(shh->id);
-}
-
-void CCDialog::Unserialize(int index, Stream *in, size_t /*data_sz*/) {
-    int num = in->ReadInt32();
+void CCDialog::Unserialize(int index, const char *serializedData, int dataSize) {
+    StartUnserialize(serializedData, dataSize);
+    int num = UnserializeInt();
     ccRegisterUnserializedObject(index, &scrDialog[num], this);
 }
