@@ -2,13 +2,13 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
 
@@ -17,16 +17,17 @@
 
 #include "ac/dynobj/cc_agsdynamicobject.h"
 
-struct CCHotspot final : AGSCCDynamicObject {
+struct CCHotspot : AGSCCDynamicObject {
 
     // return the type name of the object
-    const char *GetType() override;
-    void Unserialize(int index, AGS::Common::Stream *in, size_t data_sz) override;
-protected:
-    // Calculate and return required space for serialization, in bytes
-    size_t CalcSerializeSize(const void *address) override;
-    // Write object data into the provided stream
-    void Serialize(const void *address, AGS::Common::Stream *out) override;
+    virtual const char *GetType();
+
+    // serialize the object into BUFFER (which is BUFSIZE bytes)
+    // return number of bytes used
+    virtual int Serialize(const char *address, char *buffer, int bufsize);
+
+    virtual void Unserialize(int index, const char *serializedData, int dataSize);
+
 };
 
 #endif // __AC_CCHOTSPOT_H
\ No newline at end of file
