@@ -2,13 +2,13 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
 //
@@ -18,12 +18,8 @@
 #ifndef __AGS_EE_AC__GLOBALTRANSLATION_H
 #define __AGS_EE_AC__GLOBALTRANSLATION_H
 
-// WARNING: get_translation returns original char* if no translation is found;
-// for that reason make sure that you don't pass temporary buffer there, unless
-// you use returned value immediately or save it in another buffer.
-const char *get_translation (const char *text);
+char *get_translation (const char *text);
 int IsTranslationAvailable ();
-// GetTranslationName assumes a string buffer of MAX_MAXSTRLEN
-int GetTranslationName(char *buffer);
+int GetTranslationName (char* buffer);
 
 #endif // __AGS_EE_AC__GLOBALTRANSLATION_H
