@@ -2,13 +2,13 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
 
@@ -17,18 +17,22 @@
 
 #include "gui/newcontrol.h"
 
+#ifdef DJGPP
+#pragma warn -inl
+#endif
 struct MyLabel:public NewControl
 {
   char text[150];
-  int textheight; // TODO: use font instead
+  MyLabel(int xx, int yy, int wii, char *tee);
 
-  MyLabel(int xx, int yy, int wii, const char *tee, int textheight);
+  void draw(Common::Bitmap *ds);
 
-  void draw(Common::Bitmap *ds) override;
+  int pressedon();
 
-  int pressedon(int mx, int my) override;
-
-  int processmessage(int mcode, int wParam, intptr_t ipParam) override;
+  int processmessage(int mcode, int wParam, long lParam);
 };
+#ifdef DJGPP
+#pragma warn +inl
+#endif
 
 #endif // __AC_MYLABEL_H
\ No newline at end of file
