@@ -1,9 +1,12 @@
-#include <stdint.h>
 #include <string.h>
 
 #include "apeg.h"
 #include "mpeg1dec.h"
 
+#if defined (WINDOWS_VERSION)
+#define int64_t __int64
+#endif
+
 #ifndef NO_OGG
 
 #include <ogg/ogg.h>
@@ -473,7 +476,7 @@ unsigned char **altheora_get_frame(APEG_LAYER *layer)
 }
 
 /* Decodes Vorbis audio into the internal PCM sound buffer */
-void alvorbis_get_data(APEG_LAYER *layer)
+static void alvorbis_get_data(APEG_LAYER *layer)
 {
 	ALOGG_INFO *info = layer->ogg_info;
 
@@ -490,7 +493,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 		/* if there's pending, decoded audio, grab it */
 		if((ret = vorbis_synthesis_pcmout(&info->vdsp, &pcm)) > 0)
 		{
-			signed short *audiobuf = (signed short*)layer->audio.pcm.samples;
+			short *audiobuf = (short*)layer->audio.pcm.samples;
 			int count = layer->audio.pcm.point / 2;
 			int maxsamples = (layer->audio.bufsize-layer->audio.pcm.point) /
 			                 2 / layer->stream.audio.channels;
@@ -528,7 +531,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 					val += 65535;
 #endif
 
-					audiobuf[count++] = val - 0x7fff;
+					audiobuf[count++] = val;
 				}
 			}
 			else
@@ -547,31 +550,31 @@ void alvorbis_get_data(APEG_LAYER *layer)
 							int cval = ((pcm[info->vinfo.channels-1][i] >> 9) + 32768) * 0.70710678f;
 							for(j = 0;j < 2;++j)
 							{
-								audiobuf[count++] = (pcm[j][i] >> 9) + 32768 + cval - 0x7fff;
+								audiobuf[count++] = (pcm[j][i] >> 9) + 32768 + cval;
 							}
 							for(;j < layer->stream.audio.channels;++j)
 							{
-								audiobuf[count++] = (pcm[j][i] >> 9) + 32768 - 0x7fff;
+								audiobuf[count++] = (pcm[j][i] >> 9) + 32768;
 							}
 						}
 						else if((layer->stream.audio.channels&1))
 						{
 							for(j = 0;j < layer->stream.audio.channels-1;++j)
 							{
-								audiobuf[count++] = (pcm[j][i] >> 9) + 32768 - 0x7fff;
+								audiobuf[count++] = (pcm[j][i] >> 9) + 32768;
 							}
 							if((info->vinfo.channels&1))
 							{
-								audiobuf[count++] = (pcm[info->vinfo.channels-1][i] >> 9) + 32768 - 0x7fff;
+								audiobuf[count++] = (pcm[info->vinfo.channels-1][i] >> 9) + 32768;
 							}
 							else
-								audiobuf[count++] = 0;
+								audiobuf[count++] = 0x8000;
 						}
 						else
 						{
 							for(j = 0;j < layer->stream.audio.channels;++j)
 							{
-								audiobuf[count++] = (pcm[j][i] >> 9) + 32768 - 0x7fff;
+								audiobuf[count++] = (pcm[j][i] >> 9) + 32768;
 							}
 						}
 					}
@@ -583,7 +586,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 						for(j = 0;j < layer->stream.audio.channels;++j)
 						{
 							// Only this audio path is tested with libtremor
-							audiobuf[count++] = (pcm[j][i] >> 9) + 32768 - 0x7fff;
+							audiobuf[count++] = (pcm[j][i] >> 9) + 32768;
 						}
 					}
 				}
@@ -606,7 +609,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 								val -= 65535;
 								val &= val >> 31;
 								val += 65535;
-								audiobuf[count++] = val - 0x7fff;
+								audiobuf[count++] = val;
 							}
 							for(;j < layer->stream.audio.channels;++j)
 							{
@@ -615,7 +618,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 								val -= 65535;
 								val &= val >> 31;
 								val += 65535;
-								audiobuf[count++] = val - 0x7fff;
+								audiobuf[count++] = val;
 							}
 						}
 						else if((layer->stream.audio.channels&1))
@@ -627,7 +630,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 								val -= 65535;
 								val &= val >> 31;
 								val += 65535;
-								audiobuf[count++] = val - 0x7fff;
+								audiobuf[count++] = val;
 							}
 							if((info->vinfo.channels&1))
 							{
@@ -637,10 +640,10 @@ void alvorbis_get_data(APEG_LAYER *layer)
 								cval -= 65535;
 								cval &= cval >> 31;
 								cval += 65535;
-								audiobuf[count++] = cval - 0x7fff;
+								audiobuf[count++] = cval;
 							}
 							else
-								audiobuf[count++] = 0;
+								audiobuf[count++] = 0x8000;
 						}
 						else
 						{
@@ -651,7 +654,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 								val -= 65535;
 								val &= val >> 31;
 								val += 65535;
-								audiobuf[count++] = val - 0x7fff;
+								audiobuf[count++] = val;
 							}
 						}
 					}
@@ -667,7 +670,7 @@ void alvorbis_get_data(APEG_LAYER *layer)
 							val -= 65535;
 							val &= val >> 31;
 							val += 65535;
-							audiobuf[count++] = val - 0x7fff;
+							audiobuf[count++] = val;
 						}
 					}
 				}
