@@ -2,27 +2,29 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
 
 #include "media/audio/ambientsound.h"
-#include "media/audio/audio.h"
+#include "media/audio/audiodefines.h"
 #include "media/audio/soundclip.h"
 #include "util/stream.h"
 
 using AGS::Common::Stream;
 
+extern SOUNDCLIP *channels[MAX_SOUND_CHANNELS+1];
+
 bool AmbientSound::IsPlaying () {
     if (channel <= 0)
         return false;
-    return AudioChans::ChannelIsPlaying(channel);
+    return (channels[channel] != NULL) ? true : false;
 }
 
 void AmbientSound::ReadFromFile(Stream *in)
