@@ -2,20 +2,22 @@
 //
 // Adventure Game Studio (AGS)
 //
-// Copyright (C) 1999-2011 Chris Jones and 2011-2025 various contributors
+// Copyright (C) 1999-2011 Chris Jones and 2011-20xx others
 // The full list of copyright holders can be found in the Copyright.txt
 // file, which is part of this source code distribution.
 //
 // The AGS source code is provided under the Artistic License 2.0.
 // A copy of this license can be found in the file License.txt and at
-// https://opensource.org/license/artistic-2-0/
+// http://www.opensource.org/licenses/artistic-license-2.0.php
 //
 //=============================================================================
+
 #ifndef __AC_NAMEDPIPESAGSDEBUGGER_H
 #define __AC_NAMEDPIPESAGSDEBUGGER_H
 
 #include <windows.h>
-#include "debug/agseditordebugger.h"
+#include <io.h>
+#include "debug/debugger.h"
 
 struct NamedPipesAGSDebugger : IAGSEditorDebugger
 {
@@ -28,11 +30,11 @@ private:
 public:
 
     NamedPipesAGSDebugger(const char *instanceToken);
-    bool Initialize() override;
-    void Shutdown() override;
-    bool SendMessageToEditor(const char *message) override;
-    bool IsMessageAvailable() override;
-    char* GetNextMessage() override;
+    virtual bool Initialize();
+    virtual void Shutdown();
+    virtual bool SendMessageToEditor(const char *message);
+    virtual bool IsMessageAvailable();
+    virtual char* GetNextMessage();
 };
 
 #endif // __AC_NAMEDPIPESAGSDEBUGGER_H
